import React, { useMemo } from 'react';
import { tv } from 'tailwind-variants';
import { Nav } from '../SectioningContent';
import { StatusLabel } from '../StatusLabel';
import { AppNaviAnchor } from './AppNaviAnchor';
import { AppNaviButton } from './AppNaviButton';
import { AppNaviCustomTag } from './AppNaviCustomTag';
import { AppNaviDropdown } from './AppNaviDropdown';
const appNavi = tv({
    slots: {
        wrapper: [
            'smarthr-ui-AppNavi',
            'shr-flex shr-min-w-max shr-items-center shr-bg-white shr-px-1.5 shr-shadow-layer-1',
        ],
        statusLabel: ['smarthr-ui-AppNavi-label', 'shr-me-1'],
        buttonsEl: [
            'smarthr-ui-AppNavi-buttons',
            'shr-flex shr-items-stretch shr-gap-1 shr-self-stretch',
        ],
        listItem: ['smarthr-ui-AppNavi-listItem', 'shr-list-none'],
    },
});
export const AppNavi = ({ label, buttons, className, children, displayDropdownCaret = false, ...props }) => {
    const { wrapperStyle, statusLabelStyle, buttonsStyle, listItemStyle } = useMemo(() => {
        const { wrapper, statusLabel, buttonsEl, listItem } = appNavi();
        return {
            wrapperStyle: wrapper({ className }),
            statusLabelStyle: statusLabel(),
            buttonsStyle: buttonsEl(),
            listItemStyle: listItem(),
        };
    }, [className]);
    return (
    // eslint-disable-next-line smarthr/a11y-heading-in-sectioning-content
    React.createElement(Nav, { ...props, className: wrapperStyle },
        label && React.createElement(StatusLabel, { className: statusLabelStyle }, label),
        buttons && (React.createElement("ul", { className: buttonsStyle }, buttons.map((button, i) => {
            if ('tag' in button) {
                return (React.createElement("li", { key: i, className: listItemStyle },
                    React.createElement(AppNaviCustomTag, { ...button })));
            }
            if ('href' in button) {
                return (React.createElement("li", { key: i, className: listItemStyle },
                    React.createElement(AppNaviAnchor, { ...button })));
            }
            if ('dropdownContent' in button) {
                return (React.createElement("li", { key: i, className: listItemStyle },
                    React.createElement(AppNaviDropdown, { ...button, displayCaret: displayDropdownCaret })));
            }
            return (React.createElement("li", { key: i, className: listItemStyle },
                React.createElement(AppNaviButton, { ...button })));
        }))),
        children));
};
//# sourceMappingURL=AppNavi.js.map