import React, { useMemo } from 'react';
import { tv } from 'tailwind-variants';
import { UnstyledButton } from '../Button';
import { Dropdown, DropdownContent, DropdownTrigger } from '../Dropdown';
import { FaCaretDownIcon } from '../Icon';
import { appNaviItemStyle } from './style';
const appNaviDropdown = tv({
    extend: appNaviItemStyle,
    variants: {
        displayCaret: {
            true: {
                wrapper: [
                    'smarthr-ui-AppNavi-dropdown',
                    '[&[aria-expanded="true"]_.smarthr-ui-Icon:last-child]:shr-rotate-180',
                ],
            },
        },
        active: {
            true: {
                wrapper: 'shr-cursor-pointer',
            },
        },
    },
});
export const AppNaviDropdown = ({ children, dropdownContent, icon: Icon, current = false, displayCaret, }) => {
    const { wrapperStyle, iconStyle } = useMemo(() => {
        const { wrapper, icon } = appNaviDropdown({ active: current, displayCaret });
        return {
            wrapperStyle: wrapper(),
            iconStyle: icon(),
        };
    }, [current, displayCaret]);
    return (React.createElement(Dropdown, null,
        React.createElement(DropdownTrigger, null,
            React.createElement(UnstyledButton, { "aria-current": current ? 'page' : undefined, className: wrapperStyle },
                Icon && React.createElement(Icon, { className: iconStyle }),
                children,
                displayCaret && React.createElement(FaCaretDownIcon, null))),
        React.createElement(DropdownContent, null, dropdownContent)));
};
//# sourceMappingURL=AppNaviDropdown.js.map