import React, { useEffect, useMemo, } from 'react';
import { tv } from 'tailwind-variants';
import { Base } from '../Base';
import { Button } from '../Button';
import { Cluster, Stack } from '../Layout';
import { validateElement } from './bottomFixedAreaHelper';
const bottomFixedArea = tv({
    slots: {
        wrapper: [
            'smarthr-ui-BottomFixedArea',
            'shr-fixed shr-bottom-0 shr-z-fixed-menu shr-box-border shr-w-full shr-rounded-none shr-p-1.5 shr-text-center',
            // Layer 3 だが、上方向への指定のためベタ書き： https://smarthr.design/products/design-tokens/shadow/
            '[box-shadow:_0_-4px_8px_2px_rgba(0,_0,_0,_0.24)]',
            '[&_ul]:shr-list-none',
        ],
        tertiaryButton: [
            'smarthr-ui-BottomFixedArea-tertiaryLink',
            '-shr-mb-0.5 shr-font-normal shr-text-main',
        ],
    },
});
export const BottomFixedArea = ({ description, primaryButton, secondaryButton, tertiaryLinks, zIndex, className, ...props }) => {
    const { wrapperStyleProps, tertiaryButtonStyle } = useMemo(() => {
        const { wrapper, tertiaryButton } = bottomFixedArea();
        return {
            wrapperStyleProps: { className: wrapper({ className }), style: { zIndex } },
            tertiaryButtonStyle: tertiaryButton(),
        };
    }, [className, zIndex]);
    useEffect(() => {
        validateElement(primaryButton, secondaryButton);
    }, [primaryButton, secondaryButton]);
    return (React.createElement(Base, { ...props, ...wrapperStyleProps },
        React.createElement(Stack, null,
            description && React.createElement("p", { className: "smarthr-ui-BottomFixedArea-description" }, description),
            React.createElement(Stack, { gap: 0.25 },
                (secondaryButton || primaryButton) && (React.createElement(Cluster, { as: "ul", justify: "center", gap: { row: 0.5, column: 1 } },
                    secondaryButton && (React.createElement("li", { className: "smarthr-ui-BottomFixedArea-secondaryButton" }, secondaryButton)),
                    primaryButton && (React.createElement("li", { className: "smarthr-ui-BottomFixedArea-primaryButton" }, primaryButton)))),
                tertiaryLinks && tertiaryLinks.length > 0 && (React.createElement(Cluster, { as: "ul", justify: "center", gap: { row: 0.5, column: 0 } }, tertiaryLinks.map(({ text, icon: Icon, onClick, ...tertiaryProps }, index) => (React.createElement("li", { key: index, className: "smarthr-ui-BottomFixedArea-tertiaryListItem" },
                    React.createElement(Button, { ...tertiaryProps, variant: "text", prefix: Icon && React.createElement(Icon, null), onClick: onClick, className: tertiaryButtonStyle }, text))))))))));
};
//# sourceMappingURL=BottomFixedArea.js.map