import dayjs from 'dayjs';
import React, { forwardRef, useEffect, useMemo, useState } from 'react';
import { tv } from 'tailwind-variants';
import { useId } from '../../hooks/useId';
import { Button } from '../Button';
import { FaCaretDownIcon, FaCaretUpIcon, FaChevronLeftIcon, FaChevronRightIcon } from '../Icon';
import { Cluster } from '../Layout';
import { Section } from '../SectioningContent';
import { CalendarTable } from './CalendarTable';
import { YearPicker } from './YearPicker';
import { getFromDate, getToDate, isBetween, minDate } from './calendarHelper';
const calendar = tv({
    slots: {
        container: 'smarthr-ui-Calendar shr-inline-block shr-overflow-hidden shr-rounded-m shr-bg-white shr-text-black shr-shadow-layer-3 forced-colors:shr-border-shorthand forced-colors:shr-shadow-none',
        header: 'smarthr-ui-Calendar-header shr-border-b-shorthand shr-flex shr-items-center shr-p-1',
        yearMonth: 'smarthr-ui-Calendar-yearMonth shr-me-0.5 shr-text-base shr-font-bold',
        monthButtons: 'smarthr-ui-Calendar-monthButtons shr-ms-auto shr-flex',
        tableLayout: 'shr-relative',
    },
});
export const Calendar = forwardRef(({ from = minDate, to, onSelectDate, value, className, ...props }, ref) => {
    const { containerStyle, yearMonthStyle, headerStyle, monthButtonsStyle, tableLayoutStyle } = useMemo(() => {
        const { container, yearMonth, header, monthButtons, tableLayout } = calendar();
        return {
            containerStyle: container({ className }),
            headerStyle: header(),
            yearMonthStyle: yearMonth(),
            monthButtonsStyle: monthButtons(),
            tableLayoutStyle: tableLayout(),
        };
    }, [className]);
    const fromDate = dayjs(getFromDate(from));
    const toDate = dayjs(getToDate(to));
    const today = dayjs();
    const currentDay = toDate.isBefore(today) ? toDate : fromDate.isAfter(today) ? fromDate : today;
    const isValidValue = value && isBetween(value, fromDate.toDate(), toDate.toDate());
    const [currentMonth, setCurrentMonth] = useState(isValidValue ? dayjs(value) : currentDay);
    const [isSelectingYear, setIsSelectingYear] = useState(false);
    const yearPickerId = useId();
    useEffect(() => {
        if (value && isValidValue) {
            setCurrentMonth(dayjs(value));
        }
    }, [value, isValidValue]);
    const prevMonth = currentMonth.subtract(1, 'month');
    const nextMonth = currentMonth.add(1, 'month');
    return (
    // eslint-disable-next-line smarthr/a11y-heading-in-sectioning-content
    React.createElement(Section, { ...props, ref: ref, className: containerStyle },
        React.createElement("header", { className: headerStyle },
            React.createElement("div", { className: yearMonthStyle },
                currentMonth.year(),
                "\u5E74",
                currentMonth.month() + 1,
                "\u6708"),
            React.createElement(Button, { onClick: (e) => {
                    e.stopPropagation();
                    setIsSelectingYear(!isSelectingYear);
                }, size: "s", square: true, "aria-expanded": isSelectingYear, "aria-controls": yearPickerId, className: "smarthr-ui-Calendar-selectingYear" }, isSelectingYear ? (React.createElement(FaCaretUpIcon, { alt: "\u5E74\u3092\u9078\u629E\u3059\u308B" })) : (React.createElement(FaCaretDownIcon, { alt: "\u5E74\u3092\u9078\u629E\u3059\u308B" }))),
            React.createElement(Cluster, { gap: 0.5, className: monthButtonsStyle },
                React.createElement(Button, { disabled: isSelectingYear || prevMonth.isBefore(fromDate, 'month'), onClick: () => setCurrentMonth(prevMonth), size: "s", square: true, className: "smarthr-ui-Calendar-monthButtonPrev" },
                    React.createElement(FaChevronLeftIcon, { alt: "\u524D\u306E\u6708\u3078" })),
                React.createElement(Button, { disabled: isSelectingYear || nextMonth.isAfter(toDate, 'month'), onClick: () => setCurrentMonth(nextMonth), size: "s", square: true, className: "smarthr-ui-Calendar-monthButtonNext" },
                    React.createElement(FaChevronRightIcon, { alt: "\u6B21\u306E\u6708\u3078" })))),
        React.createElement("div", { className: tableLayoutStyle },
            React.createElement(YearPicker, { fromYear: fromDate.year(), toYear: toDate.year(), selectedYear: value?.getFullYear(), onSelectYear: (year) => {
                    setCurrentMonth(currentMonth.year(year));
                    setIsSelectingYear(false);
                }, isDisplayed: isSelectingYear, id: yearPickerId }),
            React.createElement(CalendarTable, { current: currentMonth.toDate(), from: fromDate.toDate(), to: toDate.toDate(), onSelectDate: onSelectDate, selected: isValidValue ? value : null }))));
});
//# sourceMappingURL=Calendar.js.map