import React, { useEffect, useMemo, useRef } from 'react';
import { tv } from 'tailwind-variants';
import { UnstyledButton } from '../Button';
const yearPicker = tv({
    slots: {
        overlay: 'smarthr-ui-YearPicker shr-absolute shr-inset-0 shr-bg-white',
        container: 'shr-box-border shr-flex shr-h-full shr-w-full shr-flex-wrap shr-items-start shr-overflow-y-auto shr-px-0.25 shr-py-0.5',
        yearButton: 'smarthr-ui-YearPicker-selectYear shr-group shr-flex shr-w-1/4 shr-cursor-pointer shr-items-center shr-justify-center shr-px-0 shr-py-0.5 shr-leading-none',
        yearWrapper: 'shr-box-border shr-inline-block shr-rounded-full shr-px-0.75 shr-py-0.5 shr-text-base shr-leading-none group-hover:shr-bg-base-grey group-hover:shr-text-black',
    },
    variants: {
        isDisplayed: {
            false: {
                overlay: 'shr-hidden',
            },
        },
        isThisYear: {
            true: {
                yearWrapper: 'shr-border-shorthand',
            },
        },
        isSelected: {
            true: {
                yearWrapper: 'shr-bg-main shr-text-white',
            },
        },
    },
});
export const YearPicker = ({ selectedYear, fromYear, toYear, onSelectYear, isDisplayed, id, ...props }) => {
    const { overlay, container, yearButton, yearWrapper } = yearPicker();
    const { overlayStyle, containerStyle, yearButtonStyle } = useMemo(() => ({
        overlayStyle: overlay({ isDisplayed }),
        containerStyle: container(),
        yearButtonStyle: yearButton(),
    }), [container, isDisplayed, overlay, yearButton]);
    const focusingRef = useRef(null);
    const thisYear = new Date().getFullYear();
    const numOfYear = Math.max(Math.min(toYear, 9999) - fromYear + 1, 0);
    const yearArray = Array(numOfYear)
        .fill(null)
        .map((_, i) => fromYear + i);
    useEffect(() => {
        if (focusingRef.current && isDisplayed) {
            focusingRef.current.focus();
            focusingRef.current.blur();
        }
    }, [isDisplayed]);
    return (React.createElement("div", { ...props, id: id, className: overlayStyle },
        React.createElement("div", { className: containerStyle }, yearArray.map((year) => {
            const isThisYear = thisYear === year;
            const isSelectedYear = selectedYear === year;
            return (React.createElement(UnstyledButton, { key: year, onClick: () => onSelectYear(year), "aria-pressed": isSelectedYear, ref: isThisYear ? focusingRef : null, className: yearButtonStyle },
                React.createElement("span", { className: yearWrapper({ isThisYear, isSelected: isSelectedYear }) }, year)));
        }))));
};
//# sourceMappingURL=YearPicker.js.map