import React, { useCallback, useMemo } from 'react';
import { tv } from 'tailwind-variants';
import { FaPlusCircleIcon } from '../Icon';
import { Text } from '../Text';
const button = tv({
    base: [
        'shr-block shr-min-w-full shr-cursor-pointer shr-border-none shr-px-1 shr-py-0.5 shr-text-left shr-text-base shr-leading-tight',
        'aria-selected:shr-text-white',
        'disabled:shr-cursor-not-allowed disabled:shr-text-disabled',
    ],
    variants: {
        active: {
            true: ['shr-bg-white-darken shr-text-inherit', 'aria-selected:shr-bg-main-darken'],
            false: ['shr-bg-white', 'aria-selected:shr-bg-main'],
        },
        new: {
            true: 'smarthr-ui-ComboBox-addButton shr-flex shr-items-center',
            false: 'smarthr-ui-ComboBox-selectButton',
        },
    },
});
const ListBoxItemButton = ({ option, isActive, onAdd, onSelect, onMouseOver, activeRef, }) => {
    const { item, selected, isNew } = option;
    const { label, disabled } = item;
    const handleAdd = useCallback(() => {
        onAdd(option);
    }, [onAdd, option]);
    const handleSelect = useCallback(() => {
        onSelect(option);
    }, [onSelect, option]);
    const handleMouseOver = useCallback(() => {
        onMouseOver(option);
    }, [onMouseOver, option]);
    const buttonStyle = useMemo(() => button({
        active: !!isActive,
        new: isNew,
    }), [isActive, isNew]);
    return isNew ? (
    // eslint-disable-next-line smarthr/a11y-clickable-element-has-text
    React.createElement("button", { type: "button", key: option.id, onClick: handleAdd, onMouseOver: handleMouseOver, id: option.id, role: "option", className: buttonStyle, ref: isActive ? activeRef : undefined },
        React.createElement(FaPlusCircleIcon, { color: "TEXT_LINK", text: React.createElement(Text, { color: "TEXT_LINK" },
                "\u300C",
                label,
                "\u300D\u3092\u8FFD\u52A0") }))) : (React.createElement("button", { type: "button", key: option.id, disabled: disabled, onClick: handleSelect, onMouseOver: handleMouseOver, id: option.id, role: "option", className: buttonStyle, "aria-selected": selected, ref: isActive ? activeRef : undefined }, label));
};
const typedMemo = React.memo;
const Memoized = typedMemo(ListBoxItemButton);
export { Memoized as ListBoxItemButton };
//# sourceMappingURL=ListBoxItemButton.js.map