import React, { ComponentPropsWithoutRef, InputHTMLAttributes } from 'react';
import { BaseProps, ComboBoxItem } from './types';
import type { DecoratorsType } from '../../types';
type Props<T> = BaseProps<T> & {
    /**
     * 選択されているアイテムのリスト
     */
    selectedItems: Array<ComboBoxItem<T> & {
        deletable?: boolean;
    }>;
    /**
     * 選択されているアイテムのラベルを省略表示するかどうか
     */
    selectedItemEllipsis?: boolean;
    /**
     * テキストボックスの `value` 属性の値。
     * `onChangeInput` と併せて設定することで、テキストボックスの挙動が制御可能になる。
     */
    inputValue?: string;
    /**
     * 選択されているアイテムの削除ボタンがクリックされた時に発火するコールバック関数
     */
    onDelete?: (item: ComboBoxItem<T>) => void;
    /**
     * 選択されているアイテムのリストが変わった時に発火するコールバック関数
     */
    onChangeSelected?: (selectedItems: Array<ComboBoxItem<T>>) => void;
    /**
     * コンポーネントがフォーカスされたときに発火するコールバック関数
     */
    onFocus?: () => void;
    /**
     * コンポーネントからフォーカスが外れた時に発火するコールバック関数
     */
    onBlur?: () => void;
    /**
     * コンポーネント内のテキストを変更する関数/
     */
    decorators?: DecoratorsType<'noResultText'> & {
        destroyButtonIconAlt?: (text: string) => string;
        selectedListAriaLabel?: (text: string) => string;
    };
    /**
     * アイテムが選択されたときに選択済みかどうかを判定するコールバック関数/
     */
    isItemSelected?: (targetItem: ComboBoxItem<T>, selectedItems: Array<ComboBoxItem<T>>) => boolean;
    /**
     * input 要素の属性
     */
    inputAttributes?: Omit<InputHTMLAttributes<HTMLInputElement>, 'name' | 'disabled' | 'required' | 'type' | 'aria-activedescendant' | 'aria-autocomplete' | 'aria-controls' | 'aria-disabled' | 'aria-expanded' | 'aria-haspopup' | 'aria-invalid' | 'autoComplete' | 'className' | 'onChange' | 'onCompositionEnd' | 'onCompositionStart' | 'onFocus' | 'onKeyDown' | 'ref' | 'role' | 'tabIndex' | 'value'>;
};
type ElementProps = Omit<ComponentPropsWithoutRef<'div'>, keyof Props<unknown>>;
export declare const MultiComboBox: <T>(props: BaseProps<T> & {
    /**
     * 選択されているアイテムのリスト
     */
    selectedItems: (ComboBoxItem<T> & {
        deletable?: boolean | undefined;
    })[];
    /**
     * 選択されているアイテムのラベルを省略表示するかどうか
     */
    selectedItemEllipsis?: boolean | undefined;
    /**
     * テキストボックスの `value` 属性の値。
     * `onChangeInput` と併せて設定することで、テキストボックスの挙動が制御可能になる。
     */
    inputValue?: string | undefined;
    /**
     * 選択されているアイテムの削除ボタンがクリックされた時に発火するコールバック関数
     */
    onDelete?: ((item: ComboBoxItem<T>) => void) | undefined;
    /**
     * 選択されているアイテムのリストが変わった時に発火するコールバック関数
     */
    onChangeSelected?: ((selectedItems: ComboBoxItem<T>[]) => void) | undefined;
    /**
     * コンポーネントがフォーカスされたときに発火するコールバック関数
     */
    onFocus?: (() => void) | undefined;
    /**
     * コンポーネントからフォーカスが外れた時に発火するコールバック関数
     */
    onBlur?: (() => void) | undefined;
    /**
     * コンポーネント内のテキストを変更する関数/
     */
    decorators?: (DecoratorsType<"noResultText"> & {
        destroyButtonIconAlt?: ((text: string) => string) | undefined;
        selectedListAriaLabel?: ((text: string) => string) | undefined;
    }) | undefined;
    /**
     * アイテムが選択されたときに選択済みかどうかを判定するコールバック関数/
     */
    isItemSelected?: ((targetItem: ComboBoxItem<T>, selectedItems: ComboBoxItem<T>[]) => boolean) | undefined;
    /**
     * input 要素の属性
     */
    inputAttributes?: Omit<React.InputHTMLAttributes<HTMLInputElement>, "required" | "type" | "name" | "value" | "className" | "role" | "tabIndex" | "disabled" | "ref" | "aria-activedescendant" | "aria-autocomplete" | "aria-controls" | "aria-disabled" | "aria-expanded" | "aria-haspopup" | "aria-invalid" | "onCompositionEnd" | "onCompositionStart" | "onFocus" | "onChange" | "onKeyDown" | "autoComplete"> | undefined;
} & ElementProps & React.RefAttributes<HTMLInputElement>) => React.ReactNode;
export {};
