import React, { useCallback } from 'react';
import { Button } from '../../Button';
import { Heading } from '../../Heading';
import { Cluster, Stack } from '../../Layout';
import { ResponseMessage } from '../../ResponseMessage';
import { Section } from '../../SectioningContent';
import { Text } from '../../Text';
import { useOffsetHeight } from '../dialogHelper';
import { useDialoginnerStyle } from '../useDialogInnerStyle';
const CLOSE_BUTTON_LABEL = 'キャンセル';
export const ActionDialogContentInner = ({ children, title, titleId, subtitle, titleTag, actionText, actionTheme = 'primary', onClickAction, onClickClose, responseMessage, actionDisabled = false, closeDisabled, subActionArea, decorators, }) => {
    const handleClickAction = useCallback(() => {
        onClickAction(onClickClose);
    }, [onClickAction, onClickClose]);
    const { offsetHeight, titleRef, bottomRef } = useOffsetHeight();
    const isRequestProcessing = responseMessage && responseMessage.status === 'processing';
    const { titleAreaStyle, bodyStyleProps, actionAreaStyle, buttonAreaStyle, messageStyle } = useDialoginnerStyle(offsetHeight);
    return (React.createElement(Section, null,
        React.createElement(Heading, { tag: titleTag },
            React.createElement(Stack, { gap: 0.25, as: "span", ref: titleRef, className: titleAreaStyle },
                subtitle && (React.createElement(Text, { size: "S", leading: "TIGHT", color: "TEXT_GREY", className: "smarthr-ui-Dialog-subtitle" }, subtitle)),
                React.createElement(Text, { id: titleId, size: "L", leading: "TIGHT", className: "smarthr-ui-Dialog-title" }, title))),
        React.createElement("div", { ...bodyStyleProps }, children),
        React.createElement(Stack, { gap: 0.5, ref: bottomRef, className: actionAreaStyle },
            React.createElement(Cluster, { justify: "space-between" },
                subActionArea,
                React.createElement(Cluster, { gap: { row: 0.5, column: 1 }, className: buttonAreaStyle },
                    React.createElement(Button, { onClick: onClickClose, disabled: closeDisabled || isRequestProcessing, className: "smarthr-ui-Dialog-closeButton" }, decorators?.closeButtonLabel?.(CLOSE_BUTTON_LABEL) || CLOSE_BUTTON_LABEL),
                    React.createElement(Button, { variant: actionTheme, onClick: handleClickAction, disabled: actionDisabled, loading: isRequestProcessing, className: "smarthr-ui-Dialog-actionButton" }, actionText))),
            (responseMessage?.status === 'success' || responseMessage?.status === 'error') && (React.createElement("div", { className: messageStyle },
                React.createElement(ResponseMessage, { type: responseMessage.status, role: "alert" }, responseMessage.text))))));
};
//# sourceMappingURL=ActionDialogContentInner.js.map