import React, { useCallback, useMemo, useRef, } from 'react';
import { tv } from 'tailwind-variants';
import { useHandleEscape } from '../../hooks/useHandleEscape';
import { useTheme } from '../../hooks/useTailwindTheme';
import { DialogOverlap } from './DialogOverlap';
import { DialogPositionProvider } from './DialogPositionProvider';
import { FocusTrap } from './FocusTrap';
import { useBodyScrollLock } from './useBodyScrollLock';
function exist(value) {
    return value !== undefined && value !== null;
}
const dialogContentInner = tv({
    slots: {
        layout: 'smarthr-ui-Dialog-wrapper shr-fixed shr-inset-0',
        inner: 'smarthr-ui-Dialog contrast-more:shr-border-highContrast shr-absolute shr-rounded-m shr-bg-white shr-shadow-layer-3 contrast-more:shr-border-shorthand',
        background: 'smarthr-ui-Dialog-background shr-fixed shr-inset-0 shr-bg-scrim',
    },
});
export const DialogContentInner = ({ onClickOverlay, onPressEscape = () => {
    /* noop */
}, isOpen, id, width, top, right, bottom, left, firstFocusTarget, ariaLabel, ariaLabelledby, children, className, ...props }) => {
    const { spacing } = useTheme();
    const { layoutStyle, innerStyleProps, backgroundStyle } = useMemo(() => {
        const { layout, inner, background } = dialogContentInner();
        const positionTop = exist(top) ? `${top}px` : 'auto';
        const positionRight = exist(right) ? `${right}px` : 'auto';
        const positionBottom = exist(bottom) ? `${bottom}px` : 'auto';
        const positionLeft = exist(left) ? `${left}px` : 'auto';
        const actualWidth = typeof width === 'number' ? `${width}px` : width;
        const minimumMaxWidth = `calc(100vw - max(${left || 0}px, ${spacing[0.5]}) - max(${right || 0}px, ${spacing[0.5]}))`;
        const translateX = exist(right) || exist(left) ? '0' : 'calc((100vw - 100%) / 2)';
        const translateY = exist(top) || exist(bottom) ? '0' : 'calc((100svh - 100%) / 2)';
        return {
            layoutStyle: layout(),
            innerStyleProps: {
                className: inner({ className }),
                style: {
                    inset: `${positionTop} ${positionRight} ${positionBottom} ${positionLeft}`,
                    width: exist(actualWidth) ? actualWidth : undefined,
                    maxWidth: exist(actualWidth)
                        ? `min(${minimumMaxWidth}, ${actualWidth})`
                        : minimumMaxWidth,
                    transform: `translate(${translateX}, ${translateY})`,
                },
            },
            backgroundStyle: background(),
        };
    }, [bottom, className, left, right, spacing, top, width]);
    const innerRef = useRef(null);
    useHandleEscape(useCallback(() => {
        if (!isOpen) {
            return;
        }
        onPressEscape();
    }, [isOpen, onPressEscape]));
    const handleClickOverlay = useCallback(() => {
        if (!isOpen) {
            return;
        }
        onClickOverlay && onClickOverlay();
    }, [isOpen, onClickOverlay]);
    useBodyScrollLock(isOpen);
    return (React.createElement(DialogPositionProvider, { top: top, bottom: bottom },
        React.createElement(DialogOverlap, { isOpen: isOpen },
            React.createElement("div", { className: layoutStyle, id: id },
                React.createElement("div", { onClick: handleClickOverlay, className: backgroundStyle, role: "presentation" }),
                React.createElement("div", { ...props, ...innerStyleProps, ref: innerRef, role: "dialog", "aria-label": ariaLabel, "aria-labelledby": ariaLabelledby, "aria-modal": "true" },
                    React.createElement(FocusTrap, { firstFocusTarget: firstFocusTarget }, children))))));
};
//# sourceMappingURL=DialogContentInner.js.map