import React, { useEffect, useMemo, useState } from 'react';
import { CSSTransition } from 'react-transition-group';
import { tv } from 'tailwind-variants';
const dialogOverlap = tv({
    base: [
        'shr-absolute',
        'shr-z-overlap-base',
        '[&.shr-dialog-transition-enter]:shr-opacity-0',
        '[&.shr-dialog-transition-enter-active]:shr-transition-opacity',
        '[&.shr-dialog-transition-enter-active]:shr-duration-300',
        '[&.shr-dialog-transition-enter-active]:shr-ease-in-out',
        // enter と enter-active は同時に付与されるので、enter-active を強める
        '[&&.shr-dialog-transition-enter-active]:shr-opacity-100',
        '[&.shr-dialog-transition-exit]:shr-opacity-100',
        '[&.shr-dialog-transition-exit-active]:shr-transition-opacity',
        '[&.shr-dialog-transition-exit-active]:shr-duration-300',
        '[&.shr-dialog-transition-exit-active]:shr-ease-in-out',
        // exit と exit-active は同時に付与されるので、exit-active を強める
        '[&&.shr-dialog-transition-exit-active]:shr-opacity-0',
    ],
});
export const DialogOverlap = ({ isOpen, children }) => {
    const styles = useMemo(() => dialogOverlap(), []);
    const [childrenBuffer, setChildrenBuffer] = useState(null);
    useEffect(() => {
        if (isOpen) {
            setChildrenBuffer(children);
        }
    }, [isOpen, children]);
    return (React.createElement(CSSTransition, { classNames: "shr-dialog-transition", in: isOpen, timeout: 300, unmountOnExit: true },
        React.createElement("div", { className: styles }, isOpen ? children : childrenBuffer)));
};
//# sourceMappingURL=DialogOverlap.js.map