import React, { useCallback } from 'react';
import { Button } from '../../Button';
import { Heading } from '../../Heading';
import { Cluster, Stack } from '../../Layout';
import { ResponseMessage } from '../../ResponseMessage';
import { Section } from '../../SectioningContent';
import { Text } from '../../Text';
import { useOffsetHeight } from '../dialogHelper';
import { useDialoginnerStyle } from '../useDialogInnerStyle';
const CLOSE_BUTTON_LABEL = 'キャンセル';
export const FormDialogContentInner = ({ children, title, titleId, subtitle, titleTag, actionText, actionTheme = 'primary', onSubmit, onClickClose, responseMessage, actionDisabled = false, closeDisabled, subActionArea, decorators, }) => {
    const handleSubmitAction = useCallback((e) => {
        e.preventDefault();
        // HINT: React Potals などで擬似的にformがネストしている場合など、stopPropagationを実行しないと
        // 親formが意図せずsubmitされてしまう場合がある
        e.stopPropagation();
        onSubmit(onClickClose, e);
    }, [onSubmit, onClickClose]);
    const { offsetHeight, titleRef, bottomRef } = useOffsetHeight();
    const isRequestProcessing = responseMessage && responseMessage.status === 'processing';
    const { titleAreaStyle, bodyStyleProps, actionAreaStyle, buttonAreaStyle, messageStyle } = useDialoginnerStyle(offsetHeight);
    return (React.createElement(Section, null,
        React.createElement("form", { onSubmit: handleSubmitAction },
            React.createElement(Heading, { tag: titleTag },
                React.createElement(Stack, { gap: 0.25, as: "span", ref: titleRef, className: titleAreaStyle },
                    subtitle && (React.createElement(Text, { size: "S", leading: "TIGHT", color: "TEXT_GREY", className: "smarthr-ui-Dialog-subtitle" }, subtitle)),
                    React.createElement(Text, { id: titleId, size: "L", leading: "TIGHT", className: "smarthr-ui-Dialog-title" }, title))),
            React.createElement("div", { ...bodyStyleProps }, children),
            React.createElement(Stack, { gap: 0.5, ref: bottomRef, className: actionAreaStyle },
                React.createElement(Cluster, { justify: "space-between" },
                    subActionArea,
                    React.createElement(Cluster, { gap: { row: 0.5, column: 1 }, className: buttonAreaStyle },
                        React.createElement(Button, { onClick: onClickClose, disabled: closeDisabled || isRequestProcessing, className: "smarthr-ui-Dialog-closeButton" }, decorators?.closeButtonLabel?.(CLOSE_BUTTON_LABEL) || CLOSE_BUTTON_LABEL),
                        React.createElement(Button, { type: "submit", variant: actionTheme, disabled: actionDisabled, loading: isRequestProcessing, className: "smarthr-ui-Dialog-actionButton" }, actionText))),
                (responseMessage?.status === 'success' || responseMessage?.status === 'error') && (React.createElement("div", { className: messageStyle },
                    React.createElement(ResponseMessage, { type: responseMessage.status, role: "alert" }, responseMessage.text)))))));
};
//# sourceMappingURL=FormDialogContentInner.js.map