import React, { useMemo } from 'react';
import { tv } from 'tailwind-variants';
import { Button } from '../../Button';
import { Heading } from '../../Heading';
import { Stack } from '../../Layout';
import { Section } from '../../SectioningContent';
import { Text } from '../../Text';
import { useOffsetHeight } from '../dialogHelper';
const CLOSE_BUTTON_LABEL = '閉じる';
const messegeDialogContentInner = tv({
    slots: {
        titleArea: 'smarthr-ui-Dialog-titleArea shr-border-b-shorthand shr-my-[unset] shr-px-1.5 shr-py-1',
        body: 'smarthr-ui-Dialog-description shr-overflow-auto shr-p-1.5 shr-text-base',
        footer: 'smarthr-ui-Dialog-buttonArea shr-border-t-shorthand shr-flex shr-justify-end shr-px-1.5 shr-py-1',
    },
});
export const MessageDialogContentInner = ({ title, subtitle, titleTag, titleId, description, onClickClose, decorators, }) => {
    const { offsetHeight, titleRef, bottomRef } = useOffsetHeight();
    const { titleAreaStyle, bodyStyleProps, footerStyle } = useMemo(() => {
        const { titleArea, body, footer } = messegeDialogContentInner();
        return {
            titleAreaStyle: titleArea(),
            bodyStyleProps: {
                style: {
                    maxHeight: `calc(100svh - ${offsetHeight}px)`,
                },
                className: body(),
            },
            footerStyle: footer(),
        };
    }, [offsetHeight]);
    return (React.createElement(Section, null,
        React.createElement(Heading, { tag: titleTag },
            React.createElement(Stack, { gap: 0.25, as: "span", ref: titleRef, className: titleAreaStyle },
                subtitle && (React.createElement(Text, { size: "S", color: "TEXT_GREY", className: "smarthr-ui-Dialog-subtitle" }, subtitle)),
                React.createElement(Text, { id: titleId, size: "L", className: "smarthr-ui-Dialog-title" }, title))),
        React.createElement("div", { ...bodyStyleProps }, description),
        React.createElement("footer", { ref: bottomRef, className: footerStyle },
            React.createElement(Button, { onClick: onClickClose, className: "smarthr-ui-Dialog-closeButton" }, decorators?.closeButtonLabel?.(CLOSE_BUTTON_LABEL) || CLOSE_BUTTON_LABEL))));
};
//# sourceMappingURL=MessageDialogContentInner.js.map