import React, { forwardRef, useCallback, useImperativeHandle, useMemo, useRef, useState, } from 'react';
import { tv } from 'tailwind-variants';
import { Button } from '../Button';
import { FaFolderOpenIcon } from '../Icon';
const dropZone = tv({
    slots: {
        wrapper: [
            'smarthr-ui-DropZone',
            'shr-border-shorthand shr-flex shr-flex-col shr-items-center shr-justify-center shr-bg-column shr-p-2.5',
        ],
        input: 'shr-hidden',
    },
    variants: {
        filesDraggedOver: {
            true: {
                wrapper: 'shr-border-main',
            },
            false: {
                wrapper: 'shr-border-dashed',
            },
        },
    },
});
const SELECT_BUTTON_LABEL = 'ファイルを選択';
const overrideEventDefault = (e) => {
    e.preventDefault();
    e.stopPropagation();
};
export const DropZone = forwardRef(({ children, onSelectFiles, multiple = true, decorators, ...props }, ref) => {
    const fileRef = useRef(null);
    const [filesDraggedOver, setFilesDraggedOver] = useState(false);
    const { wrapper, input } = useMemo(() => dropZone({ filesDraggedOver }), [filesDraggedOver]);
    useImperativeHandle(ref, () => fileRef.current);
    const selectButtonLabel = useMemo(() => decorators?.selectButtonLabel?.(SELECT_BUTTON_LABEL) || SELECT_BUTTON_LABEL, [decorators]);
    const onDrop = useCallback((e) => {
        overrideEventDefault(e);
        setFilesDraggedOver(false);
        onSelectFiles(e, e.dataTransfer.files);
    }, [setFilesDraggedOver, onSelectFiles]);
    const onDragOver = useCallback((e) => {
        overrideEventDefault(e);
        setFilesDraggedOver(true);
    }, [setFilesDraggedOver]);
    const onDragLeave = useCallback(() => {
        setFilesDraggedOver(false);
    }, [setFilesDraggedOver]);
    const onChange = useCallback((e) => {
        onSelectFiles(e, e.target.files);
    }, [onSelectFiles]);
    const onClickButton = () => {
        fileRef.current.click();
    };
    return (React.createElement("div", { onDrop: onDrop, onDragOver: onDragOver, onDragLeave: onDragLeave, className: wrapper() },
        children,
        React.createElement(Button, { prefix: React.createElement(FaFolderOpenIcon, null), onClick: onClickButton }, selectButtonLabel),
        React.createElement("input", { ...props, ref: fileRef, type: "file", multiple: multiple, onChange: onChange, className: input() })));
});
//# sourceMappingURL=DropZone.js.map