import React, { useMemo } from 'react';
import innerText from 'react-innertext';
import { tv } from 'tailwind-variants';
import { Button } from '../../Button';
import { FaCheckCircleIcon, FaFilterIcon, FaUndoAltIcon } from '../../Icon';
import { Cluster, Stack } from '../../Layout';
import { ResponseMessage } from '../../ResponseMessage';
import { Dropdown } from '../Dropdown';
import { DropdownCloser } from '../DropdownCloser';
import { DropdownContent } from '../DropdownContent';
import { DropdownScrollArea } from '../DropdownScrollArea';
import { DropdownTrigger } from '../DropdownTrigger';
const STATUS_FILTERED_TEXT = '適用中';
const TRIGGER_BUTTON_TEXT = '絞り込み';
const APPLY_BUTTON_TEXT = '適用';
const CANCEL_BUTTON_TEXT = 'キャンセル';
const RESET_BUTTON_TEXT = '絞り込み条件を解除';
const executeDecorator = (defaultText, decorator) => decorator?.(defaultText) || defaultText;
const filterDropdown = tv({
    slots: {
        iconWrapper: [
            'shr-relative shr-leading-none',
            '[&_>_[role="img"]_+_[role="img"]]:shr-absolute [&_>_[role="img"]_+_[role="img"]]:shr-bottom-[2px] [&_>_[role="img"]_+_[role="img"]]:shr-right-[-4px]',
        ],
        fileteredIcon: 'shr-h-[0.5em] shr-w-[0.5em]',
        statusText: 'shr-ms-0.5 shr-text-sm',
        inner: 'shr-p-1.5',
        actionArea: 'shr-border-t-shorthand shr-px-1.5 shr-py-1',
        resetButtonArea: '-shr-ms-0.5',
        rightButtonArea: 'shr-ms-auto',
        message: 'shr-text-right',
    },
    variants: {
        filtered: {
            true: {
                iconWrapper: 'shr-text-main',
            },
        },
        triggerSize: {
            default: {},
            s: {
                iconWrapper: '-shr-translate-x-0.25',
            },
        },
    },
});
export const FilterDropdown = ({ isFiltered = false, onApply, onCancel, onReset, children, hasStatusText, decorators, responseMessage, triggerSize, ...props }) => {
    const status = useMemo(() => executeDecorator(STATUS_FILTERED_TEXT, decorators?.status), [decorators]);
    const triggerButton = useMemo(() => executeDecorator(TRIGGER_BUTTON_TEXT, decorators?.triggerButton), [decorators]);
    const applyButton = useMemo(() => executeDecorator(APPLY_BUTTON_TEXT, decorators?.applyButton), [decorators]);
    const cancelButton = useMemo(() => executeDecorator(CANCEL_BUTTON_TEXT, decorators?.cancelButton), [decorators]);
    const resetButton = useMemo(() => executeDecorator(RESET_BUTTON_TEXT, decorators?.resetButton), [decorators]);
    const filteredIconAriaLabel = useMemo(() => (hasStatusText ? undefined : innerText(status)), [status, hasStatusText]);
    const isRequestProcessing = responseMessage !== undefined && responseMessage.status === 'processing';
    const { iconWrapperStyle, filteredIconStyle, statusTextStyle, innerStyle, actionAreaStyle, resetButtonAreaStyle, rightButtonAreaStyle, messageStyle, } = useMemo(() => {
        const { iconWrapper, fileteredIcon, statusText, inner, actionArea, resetButtonArea, rightButtonArea, message, } = filterDropdown();
        return {
            iconWrapperStyle: iconWrapper({ filtered: isFiltered, triggerSize }),
            filteredIconStyle: fileteredIcon(),
            statusTextStyle: statusText(),
            innerStyle: inner(),
            actionAreaStyle: actionArea(),
            resetButtonAreaStyle: resetButtonArea(),
            rightButtonAreaStyle: rightButtonArea(),
            messageStyle: message(),
        };
    }, [isFiltered, triggerSize]);
    return (React.createElement(Dropdown, null,
        React.createElement(DropdownTrigger, null,
            React.createElement(Button, { ...props, suffix: React.createElement("span", { className: iconWrapperStyle },
                    React.createElement(FaFilterIcon, null),
                    isFiltered ? (React.createElement(FaCheckCircleIcon, { "aria-label": filteredIconAriaLabel, className: filteredIconStyle })) : null), size: triggerSize }, triggerButton)),
        hasStatusText && isFiltered ? React.createElement("span", { className: statusTextStyle }, status) : null,
        React.createElement(DropdownContent, { controllable: true },
            React.createElement(DropdownScrollArea, null,
                React.createElement("div", { className: innerStyle }, children)),
            React.createElement(Stack, { gap: 0.5, className: actionAreaStyle },
                React.createElement(Cluster, { gap: 1, align: "center", justify: "space-between" },
                    onReset && (React.createElement("div", { className: resetButtonAreaStyle },
                        React.createElement(Button, { variant: "text", size: "s", prefix: React.createElement(FaUndoAltIcon, null), onClick: onReset, disabled: isRequestProcessing }, resetButton))),
                    React.createElement(Cluster, { gap: { column: 1, row: 0.5 }, justify: "flex-end", className: rightButtonAreaStyle },
                        React.createElement(DropdownCloser, null,
                            React.createElement(Button, { onClick: onCancel, disabled: isRequestProcessing }, cancelButton)),
                        React.createElement(DropdownCloser, null,
                            React.createElement(Button, { variant: "primary", onClick: onApply, loading: isRequestProcessing }, applyButton)))),
                (responseMessage?.status === 'success' || responseMessage?.status === 'error') && (React.createElement("div", { className: messageStyle },
                    React.createElement(ResponseMessage, { type: responseMessage.status, role: "alert" }, responseMessage.text)))))));
};
//# sourceMappingURL=FilterDropdown.js.map