import React, { useMemo } from 'react';
import { tv } from 'tailwind-variants';
import { PageHeading } from '../Heading';
import { Center, Stack } from '../Layout';
import { SmartHRLogo } from '../SmartHRLogo';
import { TextLink } from '../TextLink';
const errorScreen = tv({
    base: 'smarthr-ui-ErrorScreen shr-bg-background',
});
export const ErrorScreen = ({ logo = React.createElement(SmartHRLogo, { fill: "brand", className: "shr-p-0.75" }), title, links, children, footer, className, ...props }) => {
    const styles = useMemo(() => errorScreen({ className }), [className]);
    return (React.createElement(Center, { ...props, minHeight: "100vh", verticalCentering: true, className: styles },
        React.createElement(Stack, { gap: 1.5, align: "center", className: "[&&&]:shr-my-auto" },
            React.createElement("div", { className: "smarthr-ui-ErrorScreen-logo" }, logo),
            React.createElement(Stack, { align: "center" },
                title && React.createElement(PageHeading, { className: "smarthr-ui-ErrorScreen-title" }, title),
                children && React.createElement("div", { className: "smarthr-ui-ErrorScreen-content" }, children),
                links?.length && (React.createElement(Stack, { as: "ul", gap: 0.5, align: "center", className: "smarthr-ui-ErrorScreen-linkList shr-list-none" }, links.map((link, index) => (React.createElement("li", { key: index },
                    React.createElement(TextLink, { ...(link.target ? { target: link.target } : {}), href: link.url, className: "smarthr-ui-ErrorScreen-link" }, link.label)))))))),
        footer && React.createElement("div", { className: "shr-self-stretch" }, footer)));
};
//# sourceMappingURL=ErrorScreen.js.map