import React, { useMemo } from 'react';
import { tv } from 'tailwind-variants';
import { Base } from '../Base';
import { Cluster } from '../Layout';
import { ResponseMessage } from '../ResponseMessage';
const floatArea = tv({
    base: 'smarthr-ui-FloatArea shr-z-[500]',
    variants: {
        fixed: {
            true: 'shr-fixed',
            false: 'shr-sticky',
        },
        top: {
            0: 'shr-top-0',
            0.25: 'shr-top-0.25',
            0.5: 'shr-top-0.5',
            0.75: 'shr-top-0.75',
            1: 'shr-top-1',
            1.25: 'shr-top-1.25',
            1.5: 'shr-top-1.5',
            2: 'shr-top-2',
            2.5: 'shr-top-2.5',
            3: 'shr-top-3',
            3.5: 'shr-top-3.5',
            4: 'shr-top-4',
            8: 'shr-top-8',
            X3S: 'shr-top-0.25',
            XXS: 'shr-top-0.5',
            XS: 'shr-top-1',
            S: 'shr-top-1.5',
            M: 'shr-top-2',
            L: 'shr-top-2.5',
            XL: 'shr-top-3',
            XXL: 'shr-top-3.5',
            X3L: 'shr-top-4',
        },
        bottom: {
            0: 'shr-bottom-0',
            0.25: 'shr-bottom-0.25',
            0.5: 'shr-bottom-0.5',
            0.75: 'shr-bottom-0.75',
            1: 'shr-bottom-1',
            1.25: 'shr-bottom-1.25',
            1.5: 'shr-bottom-1.5',
            2: 'shr-bottom-2',
            2.5: 'shr-bottom-2.5',
            3: 'shr-bottom-3',
            3.5: 'shr-bottom-3.5',
            4: 'shr-bottom-4',
            8: 'shr-bottom-8',
            X3S: 'shr-bottom-0.25',
            XXS: 'shr-bottom-0.5',
            XS: 'shr-bottom-1',
            S: 'shr-bottom-1.5',
            M: 'shr-bottom-2',
            L: 'shr-bottom-2.5',
            XL: 'shr-bottom-3',
            XXL: 'shr-bottom-3.5',
            X3L: 'shr-bottom-4',
        },
    },
});
export const FloatArea = ({ primaryButton, secondaryButton, tertiaryButton, responseMessage, fixed = false, className, top, bottom, width, zIndex, ...rest }) => {
    const styleProps = useMemo(() => ({
        className: floatArea({
            fixed,
            top,
            bottom,
            className,
        }),
        style: { width, zIndex },
    }), [className, bottom, fixed, top, width, zIndex]);
    return (React.createElement(Base, { ...styleProps, ...rest, layer: 3, padding: 1 },
        React.createElement(Cluster, { gap: 1 },
            tertiaryButton,
            React.createElement("div", { className: "shr-ms-auto" },
                React.createElement(Cluster, { gap: 1, align: "center" },
                    (responseMessage?.status === 'success' || responseMessage?.status === 'error') && (React.createElement(ResponseMessage, { type: responseMessage.status }, responseMessage.text)),
                    React.createElement(Cluster, { gap: 1 },
                        secondaryButton,
                        primaryButton))))));
};
//# sourceMappingURL=FloatArea.js.map