import React, { useMemo } from 'react';
import { tv } from 'tailwind-variants';
import { Button } from '../../Button';
import { Dropdown, DropdownContent, DropdownScrollArea, DropdownTrigger } from '../../Dropdown';
import { Heading } from '../../Heading';
import { FaToolboxIcon } from '../../Icon';
import { Cluster, Stack } from '../../Layout';
import { Section } from '../../SectioningContent';
import { TextLink } from '../../TextLink';
const TRIGGER_LABEL = 'アプリ';
const appLauncher = tv({
    slots: {
        appsButton: [
            'shr-border-transparent shr-font-normal shr-text-white [&]:shr-bg-transparent [&]:shr-px-0.25',
            'hover:shr-border-transparent hover:[&]:shr-bg-transparent',
            'focus-visible:shr-border-transparent focus-visible:[&]:shr-bg-transparent',
        ],
        contentWrapper: ['smarthr-ui-AppLauncher', 'shr-p-1.5 shr-leading-normal'],
        category: 'smarthr-ui-AppLauncher-category',
        appList: 'shr-list-none',
        link: 'smarthr-ui-AppLauncher-link',
        footer: [
            'smarthr-ui-AppLauncher-footer',
            'shr-border-t-shorthand -shr-mx-0.75 shr-px-0.75 shr-pt-1 [&&&]:-shr-mb-0.25',
        ],
    },
});
export const AppLauncher = ({ apps, urlToShowAll, decorators, ...props }) => {
    const triggerLabel = useMemo(() => decorators?.triggerLabel?.(TRIGGER_LABEL) || TRIGGER_LABEL, [decorators]);
    const baseApps = apps.find(({ type }) => type === 'base');
    const others = apps.filter((category) => category !== baseApps);
    const { appsButton, contentWrapper, category, appList, link, footer } = appLauncher();
    return (React.createElement(Dropdown, { ...props },
        React.createElement(DropdownTrigger, null,
            React.createElement(Button, { prefix: React.createElement(FaToolboxIcon, null), className: appsButton() }, triggerLabel)),
        React.createElement(DropdownContent, { controllable: true },
            React.createElement(Stack, { as: "nav", gap: 1.5, className: contentWrapper() },
                React.createElement(DropdownScrollArea, null,
                    React.createElement(Stack, { gap: 1.5 },
                        baseApps && (React.createElement(Section, null,
                            React.createElement(Stack, { gap: 0.5, className: category() },
                                React.createElement(Heading, { type: "subSubBlockTitle" }, baseApps.heading),
                                React.createElement(Cluster, { as: "ul", gap: 1, className: appList() }, appItems(baseApps.items, link()))))),
                        React.createElement(Cluster, { gap: 1.5 }, others.map(({ heading, items }, i) => (React.createElement(Section, { key: i },
                            React.createElement(Stack, { gap: 0.5, className: category() },
                                React.createElement(Heading, { type: "subSubBlockTitle" }, heading),
                                React.createElement(Stack, { gap: 0.5, as: "ul", className: appList() }, appItems(items, link()))))))))),
                urlToShowAll && (React.createElement("div", { className: footer() },
                    React.createElement(TextLink, { href: urlToShowAll, style: { width: 'fit-content' } }, "\u3059\u3079\u3066\u898B\u308B")))))));
};
const appItems = (items, linkStyle) => items.map((item, index) => (React.createElement("li", { key: index },
    React.createElement(TextLink, { href: item.url, target: item.target, className: linkStyle }, item.label))));
//# sourceMappingURL=AppLauncher.js.map