import React, { useMemo } from 'react';
import { tv } from 'tailwind-variants';
import { Button } from '../Button';
import { Cluster } from '../Layout';
import { SmartHRLogo } from '../SmartHRLogo';
import { Text } from '../Text';
import { HeaderDropdownMenuButton } from '.';
const header = tv({
    slots: {
        wrapper: ['smarthr-ui-Header', 'shr-bg-brand shr-px-1.25', 'max-md:shr-px-0.75'],
        logoLink: [
            'smarthr-ui-Header-logoLink',
            /* ロゴが持つ padding 分だけ調整 */
            '-shr-ms-0.75',
            'focus-visible:shr-focus-indicator',
        ],
        tenantInfo: ['smarthr-ui-Header-tenantInfo', 'shr-ms-auto'],
        tenantNameText: 'shr-px-0.25',
        actions: ['smarthr-ui-Header-actions', 'shr-ms-auto'],
    },
});
export const Header = ({ logo = React.createElement(SmartHRLogo, { className: "shr-p-0.75" }), logoHref = '/', tenants, currentTenantId, onTenantSelect, children, className, }) => {
    const { wrapperStyle, logoLinkStyle, tenantInfoStyle, tenantNameTextStyle, actionsStyle } = useMemo(() => {
        const { wrapper, logoLink, tenantInfo, tenantNameText, actions } = header();
        return {
            wrapperStyle: wrapper({ className }),
            logoLinkStyle: logoLink(),
            tenantInfoStyle: tenantInfo(),
            tenantNameTextStyle: tenantNameText(),
            actionsStyle: actions(),
        };
    }, [className]);
    const currentTenantName = useMemo(() => {
        if (tenants && tenants.length >= 1) {
            const current = tenants.find(({ id }) => id === currentTenantId);
            return current ? current.name : tenants[0].name;
        }
        return undefined;
    }, [currentTenantId, tenants]);
    const tenantInfo = useMemo(() => tenants && tenants.length > 1 ? (React.createElement(HeaderDropdownMenuButton, { label: currentTenantName }, tenants.map(({ id, name }) => (React.createElement(Button, { key: id, onClick: () => onTenantSelect && onTenantSelect(id) }, name))))) : (React.createElement(Text, { color: "TEXT_WHITE", className: tenantNameTextStyle }, currentTenantName)), [currentTenantName, onTenantSelect, tenants, tenantNameTextStyle]);
    return (React.createElement(Cluster, { as: "header", justify: "space-between", gap: { column: 0.25, row: 0 }, className: wrapperStyle },
        React.createElement(Cluster, { align: "center", gap: { column: 0.25, row: 0 } },
            React.createElement("a", { href: logoHref, className: logoLinkStyle }, logo),
            currentTenantName && React.createElement("div", { className: tenantInfoStyle }, tenantInfo)),
        React.createElement(Cluster, { align: "center", justify: "flex-end", gap: { column: 0.5, row: 0.25 }, className: actionsStyle }, children)));
};
//# sourceMappingURL=Header.js.map