import React, { useMemo } from 'react';
import { tv } from 'tailwind-variants';
import { useTheme } from '../../hooks/useTailwindTheme';
import { VisuallyHiddenText } from '../VisuallyHiddenText';
export const generateIcon = (svg) => createIcon(svg);
const colorSet = {
    TEXT_BLACK: 'black',
    TEXT_WHITE: 'white',
    TEXT_GREY: 'grey',
    TEXT_DISABLED: 'disabled',
    TEXT_LINK: 'link',
    MAIN: 'main',
    DANGER: 'danger',
    WARNING: 'warning-yellow',
    BRAND: 'brand',
};
const existsColor = (color) => color in colorSet;
const fontSizeMap = {
    XXS: '2xs',
    XS: 'xs',
    S: 'sm',
    M: 'base',
    L: 'lg',
    XL: 'xl',
    XXL: '2xl',
};
const icon = tv({
    base: 'smarthr-ui-Icon group-[]/iconWrapper:shr-shrink-0 group-[]/iconWrapper:shr-translate-y-[0.125em] forced-colors:shr-fill-[CanvasText]',
});
const wrapper = tv({
    base: ['smarthr-ui-Icon-withText shr-group/iconWrapper shr-inline-flex shr-items-baseline'],
    variants: {
        gap: {
            0: 'shr-gap-x-0',
            0.25: 'shr-gap-x-0.25',
            0.5: 'shr-gap-x-0.5',
            0.75: 'shr-gap-x-0.75',
            1: 'shr-gap-x-1',
            1.25: 'shr-gap-x-1.25',
            1.5: 'shr-gap-x-1.5',
            2: 'shr-gap-x-2',
            2.5: 'shr-gap-x-2.5',
            3: 'shr-gap-x-3',
            3.5: 'shr-gap-x-3.5',
            4: 'shr-gap-x-4',
            8: 'shr-gap-x-8',
            '-0.25': '-shr-gap-x-0.25',
            '-0.5': '-shr-gap-x-0.5',
            '-0.75': '-shr-gap-x-0.75',
            '-1': '-shr-gap-x-1',
            '-1.25': '-shr-gap-x-1.25',
            '-1.5': '-shr-gap-x-1.5',
            '-2': '-shr-gap-x-2',
            '-2.5': '-shr-gap-x-2.5',
            '-3': '-shr-gap-x-3',
            '-3.5': '-shr-gap-x-3.5',
            '-4': '-shr-gap-x-4',
            '-8': '-shr-gap-x-8',
            X3S: 'shr-gap-x-0.25',
            XXS: 'shr-gap-x-0.5',
            XS: 'shr-gap-x-1',
            S: 'shr-gap-x-1.5',
            M: 'shr-gap-x-2',
            L: 'shr-gap-x-2.5',
            XL: 'shr-gap-x-3',
            XXL: 'shr-gap-x-3.5',
            X3L: 'shr-gap-x-4',
        },
    },
});
export const createIcon = (SvgIcon) => {
    const Icon = ({ color, className, role = 'img', alt, 'aria-hidden': ariaHidden, focusable = false, text, iconGap = 0.25, right = false, size, ...props }) => {
        const hasLabelByAria = props['aria-label'] !== undefined || props['aria-labelledby'] !== undefined;
        const isAriaHidden = ariaHidden !== undefined ? ariaHidden : !hasLabelByAria;
        const iconStyle = useMemo(() => icon({ className }), [className]);
        const wrapperStyle = useMemo(() => wrapper({ gap: iconGap }), [iconGap]);
        const { colors, textColor, fontSize } = useTheme();
        const replacedColor = useMemo(() => {
            if (color && existsColor(color)) {
                const colorName = colorSet[color];
                if (colorName in textColor) {
                    return textColor[colorName];
                }
                return colors[colorName];
            }
            return color;
        }, [color, colors, textColor]);
        const existsText = !!text;
        const iconSize = size ? fontSize[fontSizeMap[size]] : '1em'; // 指定がない場合は親要素のフォントサイズを継承する
        const svgIcon = (React.createElement(SvgIcon, { ...props, stroke: "currentColor", fill: "currentColor", strokeWidth: "0", 
            // size は react-icons のアイコンの大きさ、width / height は自前で SVG からアイコンを作る場合の大きさ指定
            size: iconSize, width: iconSize, height: iconSize, color: replacedColor, className: iconStyle, role: role, "aria-hidden": isAriaHidden || alt !== undefined || undefined, focusable: focusable }));
        if (existsText) {
            return (React.createElement("span", { className: wrapperStyle },
                alt && React.createElement(VisuallyHiddenText, null, alt),
                right && text,
                svgIcon,
                !right && text));
        }
        return (React.createElement(React.Fragment, null,
            alt && React.createElement(VisuallyHiddenText, null, alt),
            svgIcon));
    };
    Icon.displayName = SvgIcon.name;
    return Icon;
};
//# sourceMappingURL=generateIcon.js.map