import React, { useCallback, useEffect, useMemo, useState } from 'react';
import { tv } from 'tailwind-variants';
import { useId } from '../../hooks/useId';
import { Base } from '../Base';
import { Button } from '../Button';
import { Heading } from '../Heading';
import { FaCaretDownIcon, FaCaretUpIcon } from '../Icon';
import { Cluster, Stack } from '../Layout';
import { ResponseMessage } from '../ResponseMessage';
const OPEN_BUTTON_LABEL = '開く';
const CLOSE_BUTTON_LABEL = '閉じる';
const informationPanel = tv({
    slots: {
        wrapper: 'smarthr-ui-InformationPanel shr-p-1.5 shr-shadow-layer-3',
        header: 'smarthr-ui-InformationPanel-title',
        togglableButton: 'smarthr-ui-InformationPanel-closeButton -shr-my-0.5 shr-ms-auto',
        content: 'smarthr-ui-InformationPanel-content shr-text-base aria-hidden:shr-hidden',
    },
});
export const InformationPanel = ({ title, titleTag, type = 'info', togglable = true, active: activeProps = true, className, children, onClickTrigger, decorators, ...props }) => {
    const [active, setActive] = useState(activeProps);
    const titleId = useId();
    const contentId = useId();
    const handleClickTrigger = useCallback(() => {
        if (onClickTrigger) {
            onClickTrigger(active);
        }
        else {
            setActive(!active);
        }
    }, [active, onClickTrigger]);
    useEffect(() => {
        setActive(activeProps);
    }, [activeProps]);
    const { wrapperStyle, headerStyle, togglableButtonStyle, contentStyle } = useMemo(() => {
        const { wrapper, header, togglableButton, content } = informationPanel();
        return {
            wrapperStyle: wrapper({ className }),
            headerStyle: header(),
            togglableButtonStyle: togglableButton(),
            contentStyle: content(),
        };
    }, [className]);
    return (React.createElement(Base, { ...props, as: "section", className: wrapperStyle },
        React.createElement(Stack, { gap: 1.25 },
            React.createElement(Cluster, { align: "center", justify: "space-between" },
                React.createElement(Heading, { type: "blockTitle", tag: titleTag, id: titleId, className: headerStyle },
                    React.createElement(ResponseMessage, { type: type, iconGap: 0.5 }, title)),
                togglable && (React.createElement(Button, { suffix: active ? React.createElement(FaCaretUpIcon, null) : React.createElement(FaCaretDownIcon, null), size: "s", onClick: handleClickTrigger, "aria-expanded": togglable ? active : undefined, "aria-controls": contentId, className: togglableButtonStyle }, active
                    ? decorators?.closeButtonLabel?.(CLOSE_BUTTON_LABEL) || CLOSE_BUTTON_LABEL
                    : decorators?.openButtonLabel?.(OPEN_BUTTON_LABEL) || OPEN_BUTTON_LABEL))),
            React.createElement("div", { id: contentId, "aria-hidden": !active, className: contentStyle }, children))));
};
//# sourceMappingURL=InformationPanel.js.map