import React, { forwardRef, useEffect, useImperativeHandle, useMemo, useRef, } from 'react';
import { tv } from 'tailwind-variants';
import { useTheme } from '../../hooks/useTailwindTheme';
const bgColors = {
    BACKGRUOND: 'background',
    COLUMN: 'column',
    BASE_GREY: 'base-grey',
    OVER_BACKGROUND: 'over-background',
    HEAD: 'head',
    BORDER: 'border',
    ACTION_BACKGROUND: 'action-background',
};
const wrapper = tv({
    base: [
        'smarthr-ui-Input',
        'shr-border-shorthand shr-box-border shr-inline-flex shr-cursor-text shr-items-center shr-gap-0.5 shr-rounded-m shr-bg-white shr-px-0.5',
        'contrast-more:shr-border-high-contrast',
        'focus-within:shr-focus-indicator',
    ],
    variants: {
        disabled: {
            true: 'shr-pointer-events-none shr-bg-white-darken [&&&]:shr-border-default/50',
        },
        error: {
            true: '[&]:shr-border-danger',
        },
        readOnly: {
            true: '[&&&]:shr-border-[theme(backgroundColor.background)] [&&&]:shr-bg-background',
        },
    },
});
const inner = tv({
    slots: {
        input: [
            'smarthr-ui-Input-input',
            'shr-inline-block shr-w-full shr-grow shr-border-none shr-bg-transparent shr-py-0.75 shr-text-base shr-leading-none shr-text-black shr-outline-none shr-outline-0',
            'placeholder:shr-text-grey',
            'disabled:shr-text-disabled disabled:shr-opacity-100',
            'shr-h-[theme(fontSize.base)]',
        ],
        affix: 'shr-flex shr-shrink-0 shr-items-center shr-text-grey',
    },
});
export const Input = forwardRef(({ onFocus, onBlur, autoFocus, prefix, suffix, className, width, disabled, error, readOnly, bgColor, ...props }, ref) => {
    const innerRef = useRef(null);
    useImperativeHandle(ref, () => innerRef.current);
    const handleFocus = useMemo(() => {
        if (!onFocus) {
            return undefined;
        }
        return (e) => onFocus(e);
    }, [onFocus]);
    const handleBlur = useMemo(() => {
        if (!onBlur) {
            return undefined;
        }
        return (e) => onBlur(e);
    }, [onBlur]);
    const handleWheel = useMemo(() => (props.type === 'number' ? disableWheel : undefined), [props.type]);
    useEffect(() => {
        if (autoFocus && innerRef.current) {
            innerRef.current.focus();
        }
    }, [autoFocus]);
    const { backgroundColor } = useTheme();
    const wrapperStyleProps = useMemo(() => {
        const wrapperStyle = wrapper({ disabled, error, readOnly, className });
        const color = bgColor
            ? backgroundColor[bgColors[bgColor]]
            : undefined;
        return {
            className: wrapperStyle,
            style: {
                borderColor: color,
                backgroundColor: color,
                width: typeof width === 'number' ? `${width}px` : width,
            },
        };
    }, [backgroundColor, bgColor, className, disabled, error, readOnly, width]);
    const { input, affix } = inner();
    return (React.createElement("span", { ...wrapperStyleProps, onClick: () => innerRef.current?.focus(), role: "presentation" },
        prefix && (React.createElement("span", { className: affix({ className: 'smarthr-ui-Input-prefix' }) }, prefix)),
        React.createElement("input", { ...props, onFocus: handleFocus, onBlur: handleBlur, onWheel: handleWheel, disabled: disabled, readOnly: readOnly, ref: innerRef, "aria-invalid": error || undefined, className: input() }),
        suffix && (React.createElement("span", { className: affix({ className: 'smarthr-ui-Input-suffix' }) }, suffix))));
});
const disableWheel = (e) => {
    // wheel イベントに preventDefault はないため
    e.target && e.target.blur();
};
//# sourceMappingURL=Input.js.map