import React, { useEffect, useMemo, useRef, useState, } from 'react';
import { tv } from 'tailwind-variants';
import { Tooltip } from '../Tooltip';
const lineClamp = tv({
    base: 'smarthr-ui-LineClamp',
    variants: {
        maxLines: {
            1: 'shr-inline-block shr-w-full shr-overflow-hidden shr-overflow-ellipsis shr-whitespace-nowrap shr-align-middle',
            2: 'shr-line-clamp-[2]',
            3: 'shr-line-clamp-[3]',
            4: 'shr-line-clamp-[4]',
            5: 'shr-line-clamp-[5]',
            6: 'shr-line-clamp-[6]',
        },
    },
});
export const LineClamp = ({ maxLines = 3, children, className, ...props }) => {
    if (maxLines < 1) {
        throw new Error('"maxLines" cannot be less than 0.');
    }
    const [isTooltipVisible, setTooltipVisible] = useState(false);
    const ref = useRef(null);
    const isMultiLineOverflow = () => {
        const el = ref.current;
        return el ? el.scrollWidth > el.clientWidth || el.scrollHeight > el.clientHeight : false;
    };
    useEffect(() => {
        setTooltipVisible(isMultiLineOverflow());
    }, [maxLines, children]);
    const ActualLineClamp = () => (React.createElement("span", { ...props, className: styles, ref: ref }, children));
    const styles = useMemo(() => lineClamp({ maxLines, className }), [className, maxLines]);
    return isTooltipVisible ? (React.createElement(Tooltip, { message: children, multiLine: true, vertical: "auto" },
        React.createElement(ActualLineClamp, null))) : (React.createElement(ActualLineClamp, null));
};
//# sourceMappingURL=LineClamp.js.map