import React, { useMemo } from 'react';
import { tv } from 'tailwind-variants';
import { Cluster } from '../Layout';
import { RangeSeparator, Text } from '../Text';
const executeDecorator = (defaultText, decorator) => decorator?.(defaultText) || defaultText;
const UNIT_TOTAL_TEXT = '件中';
const UNIT_TEXT = '件';
const RANGE_SEPARATOR = '–';
const RANGE_SEPARATOR_VISUALLY_HIDDEN_TEXT = 'から';
const pageCounter = tv({ base: 'shr-text-base' });
export const PageCounter = ({ start, end, total = 0, decorators, className, ...props }) => {
    const unitTotalText = useMemo(() => executeDecorator(UNIT_TOTAL_TEXT, decorators?.unitForTotal), [decorators?.unitForTotal]);
    const unitText = useMemo(() => executeDecorator(UNIT_TEXT, decorators?.unit), [decorators?.unit]);
    const rangeSeparatorDecorators = useMemo(() => ({
        text: () => executeDecorator(RANGE_SEPARATOR, decorators?.rangeSeparator),
        visuallyHiddenText: () => executeDecorator(RANGE_SEPARATOR_VISUALLY_HIDDEN_TEXT, decorators?.rangeSeparatorVisuallyHiddenText),
    }), [decorators?.rangeSeparator, decorators?.rangeSeparatorVisuallyHiddenText]);
    const style = useMemo(() => pageCounter({ className }), [className]);
    return (React.createElement(Cluster, { ...props, inline: true, align: "baseline", className: style },
        total > 0 && (React.createElement(Cluster, { as: "span", gap: 0.25, inline: true, align: "baseline" },
            React.createElement(Text, { weight: "bold", as: "b" }, total.toLocaleString()),
            unitTotalText)),
        React.createElement(Cluster, { as: "span", gap: 0.25, inline: true, align: "baseline" },
            React.createElement(Text, { weight: "bold", as: "b" }, start.toLocaleString()),
            React.createElement(RangeSeparator, { decorators: rangeSeparatorDecorators }),
            React.createElement(Text, { weight: "bold", as: "b" }, end.toLocaleString()),
            unitText)));
};
//# sourceMappingURL=PageCounter.js.map