import React, { useMemo } from 'react';
import { tv } from 'tailwind-variants';
import { range } from '../../libs/lodash';
import { Cluster, Reel } from '../Layout';
import { Nav } from '../SectioningContent';
import { PaginationControllerItemButton } from './PaginationControllerItemButton';
import { PaginationItemButton } from './PaginationItemButton';
const pagination = tv({
    slots: {
        wrapper: 'smarthr-ui-Pagination shr-inline-block shr-max-w-full',
        list: 'shr-m-0.25 shr-list-none shr-ps-[unset]',
        firstListItem: 'smarthr-ui-Pagination-first',
        prevListItem: 'smarthr-ui-Pagination-prev',
        nextListItem: 'smarthr-ui-Pagination-next',
        lastListItem: 'smarthr-ui-Pagination-last',
    },
    variants: {
        withoutNumbers: {
            true: {
                firstListItem: 'shr-mr-0.5',
                prevListItem: 'shr-mr-0',
                nextListItem: 'shr-ml-0',
                lastListItem: 'shr-ml-0.5',
            },
            false: {
                prevListItem: 'shr-mr-0.5',
                nextListItem: 'shr-ml-0.5',
            },
        },
    },
});
export const Pagination = ({ total, current, onClick, padding = 4, className = '', withoutNumbers = false, ...props }) => {
    const { wrapper, list, firstListItem, prevListItem, nextListItem, lastListItem } = pagination();
    const { wrapperStyle, listStyle, firstListItemStyle, prevListItemStyle, nextListItemStyle, lastListItemStyle, } = useMemo(() => {
        const itemArg = { withoutNumbers };
        return {
            wrapperStyle: wrapper({ className }),
            listStyle: list(),
            firstListItemStyle: firstListItem(itemArg),
            prevListItemStyle: prevListItem(itemArg),
            nextListItemStyle: nextListItem(itemArg),
            lastListItemStyle: lastListItem(itemArg),
        };
    }, [
        className,
        withoutNumbers,
        wrapper,
        list,
        firstListItem,
        prevListItem,
        nextListItem,
        lastListItem,
    ]);
    if (total <= 1)
        return null;
    const pages = !withoutNumbers
        ? [
            ...range(current - padding, current).filter((page) => page >= 1),
            ...range(current, current + padding + 1).filter((page) => page <= total),
        ].map((page) => (React.createElement("li", { key: `pagination-${page}`, className: page === current ? 'smarthr-ui-Pagination-current' : 'smarthr-ui-Pagination-page' },
            React.createElement(PaginationItemButton, { page: page, currentPage: current, onClick: onClick }))))
        : null;
    const disabledPrev = current === 1;
    const disabledNext = current === total;
    return (
    // eslint-disable-next-line smarthr/a11y-heading-in-sectioning-content
    React.createElement(Nav, { ...props, className: wrapperStyle, "aria-label": "\u30DA\u30FC\u30B8\u30CD\u30FC\u30B7\u30E7\u30F3" },
        React.createElement(Reel, null,
            React.createElement(Cluster, { as: "ul", className: listStyle },
                React.createElement("li", { className: firstListItemStyle },
                    React.createElement(PaginationControllerItemButton, { onClick: onClick, direction: "prev", targetPage: 1, disabled: disabledPrev, double: true })),
                React.createElement("li", { className: prevListItemStyle },
                    React.createElement(PaginationControllerItemButton, { onClick: onClick, direction: "prev", targetPage: current - 1, disabled: disabledPrev })),
                pages,
                React.createElement("li", { className: nextListItemStyle },
                    React.createElement(PaginationControllerItemButton, { onClick: onClick, direction: "next", targetPage: current + 1, disabled: disabledNext })),
                React.createElement("li", { className: lastListItemStyle },
                    React.createElement(PaginationControllerItemButton, { onClick: onClick, direction: "next", targetPage: total, disabled: disabledNext, double: true }))))));
};
//# sourceMappingURL=Pagination.js.map