import React, { useCallback, useMemo, } from 'react';
import { tv } from 'tailwind-variants';
import { isMobileSafari } from '../../libs/ua';
import { genericsForwardRef } from '../../libs/util';
import { FaSortIcon } from '../Icon';
const BLANK_LABEL = '選択してください';
const select = tv({
    slots: {
        wrapper: 'smarthr-ui-Select shr-relative shr-inline-block',
        selectEl: [
            'shr-peer shr-border-shorthand shr-w-full shr-cursor-pointer shr-appearance-none shr-rounded-m shr-bg-white shr-text-base shr-leading-tight shr-text-black shr-outline-none',
            'hover:shr-bg-white-darken',
            'focus-visible:shr-focus-indicator',
            'disabled:shr-pointer-events-none disabled:shr-bg-white-darken disabled:shr-text-disabled disabled:shr-opacity-100',
            'contrast-more:shr-border-r-highContrast',
            /* padding に依る積み上げでは文字が見切れてしまうため */
            'shr-min-h-[calc(theme(fontSize.base)_+_theme(spacing[0.75])_*_2_+_theme(spacing.px)_*_2)]',
        ],
        iconWrap: [
            'shr-pointer-events-none shr-absolute shr-inset-y-0 shr-inline-flex shr-items-center shr-text-grey',
            'peer-focus-visible:shr-text-black peer-disabled:shr-text-disabled',
        ],
        blankOptgroup: 'shr-hidden',
    },
    variants: {
        size: {
            default: {
                selectEl: 'shr-py-0.5 shr-pe-2 shr-ps-0.5',
                iconWrap: 'shr-end-0.75',
            },
            s: {
                selectEl: [
                    'shr-px-0.5 shr-py-0.25 shr-text-sm',
                    /* padding に依る積み上げでは文字が見切れてしまうため */
                    'shr-min-h-[calc(theme(fontSize.sm)_+_theme(spacing[0.5])_*_2_+_theme(spacing.px)_*_2)]',
                ],
                iconWrap: 'shr-end-0.5 shr-text-sm',
            },
        },
        error: {
            true: {
                selectEl: 'shr-border-danger',
            },
            false: {
                selectEl: 'shr-border-default disabled:shr-border-disabled',
            },
        },
    },
});
const ActualSelect = ({ options, onChange, onChangeValue, error = false, width, hasBlank = false, decorators, size = 'default', className, disabled, ...props }, ref) => {
    const handleChange = useCallback((e) => {
        if (onChange)
            onChange(e);
        if (onChangeValue) {
            const flattenOptions = options.reduce((pre, cur) => pre.concat('value' in cur ? cur : cur.options), []);
            const selectedOption = flattenOptions.find((option) => option.value === e.target.value);
            if (selectedOption) {
                onChangeValue(selectedOption.value);
            }
        }
    }, [onChange, onChangeValue, options]);
    const { wrapperStyleProps, selectStyle, iconWrapStyle, blankOptGroupStyle } = useMemo(() => {
        const { wrapper, selectEl, iconWrap, blankOptgroup } = select();
        return {
            wrapperStyleProps: {
                className: wrapper({ className }),
                style: {
                    width: typeof width === 'number' ? `${width}px` : width,
                },
            },
            selectStyle: selectEl({ error, size }),
            iconWrapStyle: iconWrap({ size }),
            blankOptGroupStyle: blankOptgroup(),
        };
    }, [className, error, size, width]);
    return (React.createElement("span", { ...wrapperStyleProps },
        React.createElement("select", { ...props, onChange: handleChange, "aria-invalid": error || undefined, disabled: disabled, ref: ref, className: selectStyle },
            hasBlank && (React.createElement("option", { value: "" }, decorators?.blankLabel?.(BLANK_LABEL) || BLANK_LABEL)),
            options.map((option) => {
                if ('value' in option) {
                    return (React.createElement("option", { ...option, key: option.value }, option.label));
                }
                const { options: groupedOptions, ...optgroup } = option;
                return (React.createElement("optgroup", { ...optgroup, key: optgroup.label }, groupedOptions.map((groupedOption) => (React.createElement("option", { ...groupedOption, key: groupedOption.value }, groupedOption.label)))));
            }),
            // Support for not omitting labels in Mobile Safari
            isMobileSafari && React.createElement("optgroup", { className: blankOptGroupStyle })),
        React.createElement("span", { className: iconWrapStyle },
            React.createElement(FaSortIcon, null))));
};
export const Select = genericsForwardRef(ActualSelect);
//# sourceMappingURL=Select.js.map