import React, { useMemo } from 'react';
import { tv } from 'tailwind-variants';
import { FaExclamationCircleIcon, FaExclamationTriangleIcon } from '../Icon';
const statusLabel = tv({
    base: [
        'smarthr-ui-StatusLabel',
        'shr-box-content',
        'shr-font-bold',
        'shr-inline-flex',
        'shr-items-center',
        'shr-justify-center',
        'shr-gap-0.25',
        'shr-px-0.5',
        'shr-py-0.25',
        'shr-whitespace-nowrap',
        'shr-text-sm',
        // ラベルが天地中央に揃わないため暫定対応
        'shr-leading-[0]',
        'shr-min-w-[3.5em]',
        'shr-min-h-em',
        'shr-border-shorthand',
    ],
    variants: {
        type: {
            grey: [],
            blue: [],
            green: [],
            red: [],
            warning: ['shr-bg-warning-yellow', 'shr-text-black'],
            error: ['shr-bg-danger', 'shr-border-danger', 'shr-text-white'],
        },
        bold: {
            true: [],
        },
    },
    compoundVariants: [
        {
            type: ['blue', 'green', 'red', 'warning'],
            bold: false,
            className: ['shr-border-current'],
        },
        {
            type: ['grey', 'blue', 'green', 'red'],
            bold: false,
            className: ['shr-bg-white'],
        },
        {
            type: 'grey',
            bold: false,
            class: ['shr-border-grey-20', 'shr-text-grey', 'contrast-more:shr-border-high-contrast'],
        },
        {
            type: 'blue',
            bold: false,
            class: ['shr-text-main'],
        },
        {
            type: 'green',
            bold: false,
            /* SmartHR 基本色の Aqua04。StatusLabel 以外では使いません。
             * https://smarthr.design/basics/colors/#h4-1 */
            class: ['shr-text-[#0f7f85]'],
        },
        {
            type: 'red',
            bold: false,
            class: ['shr-text-danger'],
        },
        {
            type: 'warning',
            bold: false,
            class: ['shr-border-warning-yellow'],
        },
        {
            type: ['grey', 'blue', 'green', 'red', 'error'],
            bold: true,
            class: ['shr-text-white'],
        },
        {
            type: 'grey',
            bold: true,
            class: ['shr-bg-[theme(colors.grey.65)]', 'shr-border-grey-65'],
        },
        {
            type: 'blue',
            bold: true,
            class: ['shr-bg-main', 'shr-border-main'],
        },
        {
            type: 'green',
            bold: true,
            /* SmartHR 基本色の Aqua04。StatusLabel 以外では使いません。
             * https://smarthr.design/basics/colors/#h4-1 */
            class: ['shr-border-[#0f7f85]', 'shr-bg-[#0f7f85]'],
        },
        {
            type: 'red',
            bold: true,
            class: ['shr-bg-danger', 'shr-border-danger'],
        },
        {
            type: 'warning',
            bold: true,
            class: ['shr-border-current', 'shr-text-black'],
        },
    ],
});
export const StatusLabel = ({ type = 'grey', bold = false, className, children, ...props }) => {
    const Icon = useMemo(() => {
        switch (true) {
            case type === 'warning' && bold: {
                return FaExclamationTriangleIcon;
            }
            case type === 'error' && bold: {
                return FaExclamationCircleIcon;
            }
            default: {
                return React.Fragment;
            }
        }
    }, [type, bold]);
    const wrapperStyle = useMemo(() => statusLabel({
        className,
        type,
        bold,
    }), [className, type, bold]);
    return (React.createElement("span", { ...props, className: wrapperStyle },
        React.createElement(Icon, null),
        children));
};
//# sourceMappingURL=StatusLabel.js.map