import React, { useMemo } from 'react';
import { tv } from 'tailwind-variants';
import { Center } from '../Layout';
import { Td } from './Td';
import { useTableHeadCellCount } from './useTableHeadCellCount';
const emptyTableBodyCell = tv({
    base: '',
    variants: {
        paddingBlock: {
            0: 'shr-py-0',
            0.25: 'shr-py-0.25',
            0.5: 'shr-py-0.5',
            0.75: 'shr-py-0.75',
            1: 'shr-py-1',
            1.25: 'shr-py-1.25',
            1.5: 'shr-py-1.5',
            2: 'shr-py-2',
            2.5: 'shr-py-2.5',
            3: 'shr-py-3',
            3.5: 'shr-py-3.5',
            4: 'shr-py-4',
            8: 'shr-py-8',
            X3S: 'shr-py-0.25',
            XXS: 'shr-py-0.5',
            XS: 'shr-py-1',
            S: 'shr-py-1.5',
            M: 'shr-py-2',
            L: 'shr-py-2.5',
            XL: 'shr-py-3',
            XXL: 'shr-py-3.5',
            X3L: 'shr-py-4',
        },
        paddingInline: {
            0: 'shr-px-0',
            0.25: 'shr-px-0.25',
            0.5: 'shr-px-0.5',
            0.75: 'shr-px-0.75',
            1: 'shr-px-1',
            1.25: 'shr-px-1.25',
            1.5: 'shr-px-1.5',
            2: 'shr-px-2',
            2.5: 'shr-px-2.5',
            3: 'shr-px-3',
            3.5: 'shr-px-3.5',
            4: 'shr-px-4',
            8: 'shr-px-8',
            X3S: 'shr-px-0.25',
            XXS: 'shr-px-0.5',
            XS: 'shr-px-1',
            S: 'shr-px-1.5',
            M: 'shr-px-2',
            L: 'shr-px-2.5',
            XL: 'shr-px-3',
            XXL: 'shr-px-3.5',
            X3L: 'shr-px-4',
        },
    },
});
export const EmptyTableBody = ({ children, padding = 4, ...props }) => {
    const { countHeadCellRef, count } = useTableHeadCellCount();
    const tdStyles = useMemo(() => {
        const paddingBlock = padding instanceof Object ? padding.vertical : padding;
        const paddingInline = padding instanceof Object ? padding.horizontal : padding;
        return emptyTableBodyCell({
            paddingBlock,
            paddingInline,
        });
    }, [padding]);
    return (React.createElement("tbody", { ...props, ref: countHeadCellRef },
        React.createElement("tr", null,
            React.createElement(Td, { colSpan: count, className: tdStyles },
                React.createElement(Center, null, children)))));
};
//# sourceMappingURL=EmptyTableBody.js.map