import React, { forwardRef, useMemo } from 'react';
import { tv } from 'tailwind-variants';
import { CheckBox } from '../CheckBox';
import { Center } from '../Layout';
import { VisuallyHiddenText } from '../VisuallyHiddenText';
import { Td } from './Td';
const tdCheckbox = tv({
    slots: {
        inner: 'shr-absolute shr-inset-0 [&:not(:has([disabled]))]:shr-cursor-pointer',
        wrapper: 'shr-relative shr-w-[theme(fontSize.base)] [&]:shr-p-0.75',
        checkbox: '[&]:shr-block',
    },
});
export const TdCheckbox = forwardRef(({ 'aria-labelledby': ariaLabelledby, children, className, ...others }, ref) => {
    const { wrapperStyle, innerStyle, checkboxStyle } = useMemo(() => {
        const { wrapper, inner, checkbox } = tdCheckbox();
        return {
            wrapperStyle: wrapper({ className }),
            innerStyle: inner(),
            checkboxStyle: checkbox(),
        };
    }, [className]);
    return (
    // Td に必要な属性やイベントは不要
    React.createElement(Td, { className: wrapperStyle },
        React.createElement(Center, { as: "label", verticalCentering: true, className: innerStyle },
            React.createElement(CheckBox, { ...others, ref: ref, "aria-labelledby": ariaLabelledby, className: checkboxStyle }),
            children && React.createElement(VisuallyHiddenText, null, children))));
});
//# sourceMappingURL=TdCheckbox.js.map