import React, { useMemo, } from 'react';
import { tv } from 'tailwind-variants';
import { UnstyledButton } from '../Button';
import { FaSortDownIcon, FaSortUpIcon } from '../Icon';
import { VisuallyHiddenText } from '../VisuallyHiddenText';
import { reelShadowStyle } from './useReelShadow';
const SORT_DIRECTION_LABEL = {
    asc: '昇順',
    desc: '降順',
    none: '並び替えなし',
};
const thWrapper = tv({
    base: [
        'smarthr-ui-Th',
        'shr-px-1 shr-py-0.75 shr-text-left shr-align-middle shr-text-sm shr-font-bold shr-leading-tight shr-text-black',
        'aria-[sort]:shr-cursor-pointer',
        'hover:aria-[sort]:shr-bg-head-darken',
        '[&:has(:focus-visible)]:aria-[sort]:shr-focus-indicator',
        '[&[aria-sort=none]_.smarthr-ui-Icon]:forced-colors:shr-fill-[GrayText]',
        '[&[aria-sort=ascending]_.smarthr-ui-Icon:first-of-type]:forced-colors:shr-fill-[CanvasText] [&[aria-sort=ascending]_.smarthr-ui-Icon:last-of-type]:forced-colors:shr-fill-[GrayText]',
        '[&[aria-sort=descending]_.smarthr-ui-Icon:first-of-type]:forced-colors:shr-fill-[GrayText] [&[aria-sort=descending]_.smarthr-ui-Icon:last-of-type]:forced-colors:shr-fill-[CanvasText]',
    ],
    variants: {
        fixed: {
            true: [
                /* これ以降の記述はTableReel内で'fixed'を利用した際に追従させるために必要 */
                'fixedElement',
                '[&.fixed]:shr-sticky [&.fixed]:shr-right-0 [&.fixed]:after:shr-opacity-100',
            ],
        },
    },
});
export const Th = ({ children, sort, onSort, decorators, fixed = false, className, ...props }) => {
    const styles = useMemo(() => {
        const thWrapperStyle = thWrapper({ className, fixed });
        const reelShadowStyles = fixed ? reelShadowStyle({ showShadow: false, direction: 'right' }) : '';
        return `${thWrapperStyle} ${reelShadowStyles}`.trim();
    }, [className, fixed]);
    const sortLabel = useMemo(() => sort &&
        (decorators?.sortDirectionIconAlt?.(SORT_DIRECTION_LABEL[sort], { sort }) ||
            SORT_DIRECTION_LABEL[sort]), [decorators, sort]);
    const ariaSortProps = useMemo(() => sort && {
        'aria-sort': sort === 'none' ? 'none' : `${sort}ending`,
    }, [sort]);
    return (React.createElement("th", { ...ariaSortProps, ...props, className: styles }, sort ? (React.createElement(SortButton, { onClick: onSort },
        children,
        React.createElement(SortIcon, { sort: sort }),
        React.createElement(VisuallyHiddenText, null, sortLabel))) : (children)));
};
const sortButton = tv({
    base: [
        '-shr-mx-1 -shr-my-0.75 shr-inline-flex shr-w-full shr-justify-between shr-gap-x-0.5 shr-px-1 shr-py-0.75 shr-font-bold',
        // UnstyledButton に stretch がなぜか指定されてて負けてしまうため（UnstyledButton を見直した方がよさそう）
        '[&]:shr-items-center',
    ],
});
const SortButton = ({ className, ...props }) => {
    const sortButtonStyle = useMemo(() => sortButton({ className }), [className]);
    return React.createElement(UnstyledButton, { ...props, className: sortButtonStyle });
};
const sortIcon = tv({
    slots: {
        wrapper: 'shr-inline-flex shr-flex-col',
        upIcon: 'shr-text-base',
        downIcon: '-shr-mt-em shr-text-base',
    },
    variants: {
        sort: {
            asc: {
                upIcon: 'shr-text-black',
                downIcon: 'shr-text-disabled',
            },
            desc: {
                upIcon: 'shr-text-disabled',
                downIcon: 'shr-text-black',
            },
            none: {
                upIcon: 'shr-text-disabled',
                downIcon: 'shr-text-disabled',
            },
        },
    },
});
const SortIcon = ({ sort }) => {
    const { wrapperStyle, upIconStyle, downIconStyle } = useMemo(() => {
        const sortIconStyle = sortIcon();
        return {
            wrapperStyle: sortIconStyle.wrapper(),
            upIconStyle: sortIconStyle.upIcon({ sort }),
            downIconStyle: sortIconStyle.downIcon({ sort }),
        };
    }, [sort]);
    return (React.createElement("span", { className: wrapperStyle },
        React.createElement(FaSortUpIcon, { className: upIconStyle }),
        React.createElement(FaSortDownIcon, { className: downIconStyle })));
};
//# sourceMappingURL=Th.js.map