import React, { useMemo } from 'react';
import { tv } from 'tailwind-variants';
import { MAPPER_SIZE_AND_WEIGHT } from '../Heading/Heading';
const text = tv({
    variants: {
        size: {
            XXS: 'shr-text-2xs',
            XS: 'shr-text-xs',
            S: 'shr-text-sm',
            M: 'shr-text-base',
            L: 'shr-text-lg',
            XL: 'shr-text-xl',
            XXL: 'shr-text-2xl',
        },
        weight: {
            normal: 'shr-font-normal',
            bold: 'shr-font-bold',
        },
        italic: {
            true: 'shr-italic',
        },
        color: {
            TEXT_BLACK: 'shr-text-black',
            TEXT_WHITE: 'shr-text-white',
            TEXT_GREY: 'shr-text-grey',
            TEXT_DISABLED: 'shr-text-disabled',
            TEXT_LINK: 'shr-text-link',
            inherit: 'shr-text-inherit',
        },
        leading: {
            NONE: 'shr-leading-none',
            TIGHT: 'shr-leading-tight',
            NORMAL: 'shr-leading-normal',
            LOOSE: 'shr-leading-loose',
        },
        whiteSpace: {
            normal: 'shr-whitespace-normal',
            nowrap: 'shr-whitespace-nowrap',
            pre: 'shr-whitespace-pre',
            'pre-line': 'shr-whitespace-pre-line',
            'pre-wrap': 'shr-whitespace-pre-wrap',
        },
    },
});
export const Text = ({ emphasis, styleType, weight = emphasis ? 'bold' : undefined, as: Component = emphasis ? 'em' : 'span', ...props }) => {
    const { size, italic, color, leading, whiteSpace, className, ...others } = props;
    const styleTypeValues = styleType ? MAPPER_SIZE_AND_WEIGHT[styleType] : null;
    const styles = useMemo(() => text({
        size: size || styleTypeValues?.size,
        weight: weight || styleTypeValues?.weight,
        color: color || styleTypeValues?.color,
        italic,
        leading,
        whiteSpace,
        className,
    }), [size, weight, italic, color, leading, whiteSpace, className, styleTypeValues]);
    return React.createElement(Component, { ...others, className: styles });
};
//# sourceMappingURL=Text.js.map