import React, { forwardRef, useMemo } from 'react';
import { tv } from 'tailwind-variants';
import { FaExternalLinkAltIcon } from '../Icon';
const textLink = tv({
    slots: {
        anchor: 'shr-text-link shr-no-underline shr-shadow-underline forced-colors:shr-underline [&:not([href])]:shr-shadow-none [&:not([href])]:forced-colors:shr-no-underline',
        prefixWrapper: 'shr-me-0.25 shr-align-middle',
        suffixWrapper: 'shr-ms-0.25 shr-align-middle',
    },
});
export const TextLink = forwardRef(({ href, target, onClick, children, prefix, suffix, className, ...others }, ref) => {
    const actualSuffix = useMemo(() => {
        if (target === '_blank' && suffix === undefined) {
            return React.createElement(FaExternalLinkAltIcon, { "aria-label": "\u5225\u30BF\u30D6\u3067\u958B\u304F" });
        }
        return suffix;
    }, [suffix, target]);
    const actualHref = useMemo(() => {
        if (href) {
            return href;
        }
        if (onClick) {
            return '';
        }
        return undefined;
    }, [href, onClick]);
    const actualOnClick = useMemo(() => {
        if (!onClick) {
            return undefined;
        }
        return (e) => {
            if (!href) {
                e.preventDefault();
            }
            onClick(e);
        };
    }, [href, onClick]);
    const { anchor, prefixWrapper, suffixWrapper } = useMemo(() => textLink(), []);
    return (React.createElement("a", { ...others, ref: ref, href: actualHref, target: target, onClick: actualOnClick, className: anchor({ className }) },
        prefix && React.createElement("span", { className: prefixWrapper() }, prefix),
        children,
        actualSuffix && React.createElement("span", { className: suffixWrapper() }, actualSuffix)));
});
//# sourceMappingURL=TextLink.js.map