"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Button = void 0;
const react_1 = __importStar(require("react"));
const tailwind_variants_1 = require("tailwind-variants");
const usePortal_1 = require("../../hooks/usePortal");
const Icon_1 = require("../Icon");
const Layout_1 = require("../Layout");
const Loader_1 = require("../Loader");
const Tooltip_1 = require("../Tooltip");
const VisuallyHiddenText_1 = require("../VisuallyHiddenText");
const ButtonInner_1 = require("./ButtonInner");
const ButtonWrapper_1 = require("./ButtonWrapper");
const buttonStyle = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: 'smarthr-ui-Button',
        loader: 'shr-align-bottom [&&&_.smarthr-ui-Loader-spinner]:shr-h-em [&&&_.smarthr-ui-Loader-spinner]:shr-w-em',
        disabledWrapper: 'smarthr-ui-Button-disabledWrapper',
        disabledTooltip: [
            '[&&&]:shr-overflow-y-visible',
            /* Tooltip との距離を変えずに反応範囲を広げるために negative space を使う */
            '[&_.smarthr-ui-Icon]:-shr-m-0.25',
            /* global styleなどでborder-boxが適用されている場合表示崩れを起こす為、content-boxを指定する */
            '[&_.smarthr-ui-Icon]:shr-box-content',
            '[&_.smarthr-ui-Icon]:shr-p-0.25',
            '[&_.smarthr-ui-Icon]:shr-text-grey',
        ],
    },
    variants: {
        isSecondary: {
            true: {
                loader: '[&&&_.smarthr-ui-Loader-line]:shr-border-disabled',
            },
            false: {
                loader: '[&&&_.smarthr-ui-Loader-line]:shr-border-white/50',
            },
        },
    },
});
const LOADING_TEXT = '処理中';
exports.Button = (0, react_1.forwardRef)(({ type = 'button', size = 'default', square = false, prefix, suffix, wide = false, variant = 'secondary', disabled, disabledDetail, className, children, loading = false, decorators, ...props }, ref) => {
    const { wrapper, loader: loaderSlot, disabledWrapper, disabledTooltip } = buttonStyle();
    const wrapperStyle = (0, react_1.useMemo)(() => wrapper({ className }), [className, wrapper]);
    const loaderStyle = (0, react_1.useMemo)(() => loaderSlot({ isSecondary: variant === 'secondary' }), [loaderSlot, variant]);
    const { createPortal } = (0, usePortal_1.usePortal)();
    const loader = react_1.default.createElement(Loader_1.Loader, { size: "s", className: loaderStyle, role: "presentation" });
    const actualPrefix = !loading && prefix;
    const actualSuffix = loading && !square ? loader : suffix;
    const disabledOnLoading = loading || disabled;
    const actualChildren = loading && square ? loader : children;
    const statusText = (0, react_1.useMemo)(() => {
        const loadingText = decorators?.loading?.(LOADING_TEXT) ?? LOADING_TEXT;
        return loading ? loadingText : '';
    }, [decorators, loading]);
    const button = (react_1.default.createElement(ButtonWrapper_1.ButtonWrapper, { ...props, type: type, size: size, square: square, wide: wide, variant: variant, className: wrapperStyle, buttonRef: ref, disabled: disabledOnLoading, "$loading": loading },
        // `button` 要素内で live region を使うことはできないので、`role="status"` を持つ要素を外側に配置している。 https://github.com/kufu/smarthr-ui/pull/4558
        createPortal(react_1.default.createElement(VisuallyHiddenText_1.VisuallyHiddenText, { role: "status" }, statusText)),
        react_1.default.createElement(ButtonInner_1.ButtonInner, { prefix: actualPrefix, suffix: actualSuffix, size: size }, actualChildren)));
    if (disabled && disabledDetail) {
        const DisabledDetailIcon = disabledDetail.icon || Icon_1.FaInfoCircleIcon;
        return (react_1.default.createElement(Layout_1.Cluster, { inline: true, align: "center", gap: 0.25, className: disabledWrapper() },
            button,
            react_1.default.createElement(Tooltip_1.Tooltip, { message: disabledDetail.message, triggerType: "icon", horizontal: "auto", vertical: "auto", className: disabledTooltip() },
                react_1.default.createElement(DisabledDetailIcon, null))));
    }
    return button;
});
// BottomFixedArea での判定に用いるために displayName を明示的に設定する
exports.Button.displayName = 'Button';
//# sourceMappingURL=Button.js.map