"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Calendar = void 0;
const dayjs_1 = __importDefault(require("dayjs"));
const react_1 = __importStar(require("react"));
const tailwind_variants_1 = require("tailwind-variants");
const useId_1 = require("../../hooks/useId");
const Button_1 = require("../Button");
const Icon_1 = require("../Icon");
const Layout_1 = require("../Layout");
const SectioningContent_1 = require("../SectioningContent");
const CalendarTable_1 = require("./CalendarTable");
const YearPicker_1 = require("./YearPicker");
const calendarHelper_1 = require("./calendarHelper");
const calendar = (0, tailwind_variants_1.tv)({
    slots: {
        container: 'smarthr-ui-Calendar shr-inline-block shr-overflow-hidden shr-rounded-m shr-bg-white shr-text-black shr-shadow-layer-3 forced-colors:shr-border-shorthand forced-colors:shr-shadow-none',
        header: 'smarthr-ui-Calendar-header shr-border-b-shorthand shr-flex shr-items-center shr-p-1',
        yearMonth: 'smarthr-ui-Calendar-yearMonth shr-me-0.5 shr-text-base shr-font-bold',
        monthButtons: 'smarthr-ui-Calendar-monthButtons shr-ms-auto shr-flex',
        tableLayout: 'shr-relative',
    },
});
exports.Calendar = (0, react_1.forwardRef)(({ from = calendarHelper_1.minDate, to, onSelectDate, value, className, ...props }, ref) => {
    const { containerStyle, yearMonthStyle, headerStyle, monthButtonsStyle, tableLayoutStyle } = (0, react_1.useMemo)(() => {
        const { container, yearMonth, header, monthButtons, tableLayout } = calendar();
        return {
            containerStyle: container({ className }),
            headerStyle: header(),
            yearMonthStyle: yearMonth(),
            monthButtonsStyle: monthButtons(),
            tableLayoutStyle: tableLayout(),
        };
    }, [className]);
    const fromDate = (0, dayjs_1.default)((0, calendarHelper_1.getFromDate)(from));
    const toDate = (0, dayjs_1.default)((0, calendarHelper_1.getToDate)(to));
    const today = (0, dayjs_1.default)();
    const currentDay = toDate.isBefore(today) ? toDate : fromDate.isAfter(today) ? fromDate : today;
    const isValidValue = value && (0, calendarHelper_1.isBetween)(value, fromDate.toDate(), toDate.toDate());
    const [currentMonth, setCurrentMonth] = (0, react_1.useState)(isValidValue ? (0, dayjs_1.default)(value) : currentDay);
    const [isSelectingYear, setIsSelectingYear] = (0, react_1.useState)(false);
    const yearPickerId = (0, useId_1.useId)();
    (0, react_1.useEffect)(() => {
        if (value && isValidValue) {
            setCurrentMonth((0, dayjs_1.default)(value));
        }
    }, [value, isValidValue]);
    const prevMonth = currentMonth.subtract(1, 'month');
    const nextMonth = currentMonth.add(1, 'month');
    return (
    // eslint-disable-next-line smarthr/a11y-heading-in-sectioning-content
    react_1.default.createElement(SectioningContent_1.Section, { ...props, ref: ref, className: containerStyle },
        react_1.default.createElement("header", { className: headerStyle },
            react_1.default.createElement("div", { className: yearMonthStyle },
                currentMonth.year(),
                "\u5E74",
                currentMonth.month() + 1,
                "\u6708"),
            react_1.default.createElement(Button_1.Button, { onClick: (e) => {
                    e.stopPropagation();
                    setIsSelectingYear(!isSelectingYear);
                }, size: "s", square: true, "aria-expanded": isSelectingYear, "aria-controls": yearPickerId, className: "smarthr-ui-Calendar-selectingYear" }, isSelectingYear ? (react_1.default.createElement(Icon_1.FaCaretUpIcon, { alt: "\u5E74\u3092\u9078\u629E\u3059\u308B" })) : (react_1.default.createElement(Icon_1.FaCaretDownIcon, { alt: "\u5E74\u3092\u9078\u629E\u3059\u308B" }))),
            react_1.default.createElement(Layout_1.Cluster, { gap: 0.5, className: monthButtonsStyle },
                react_1.default.createElement(Button_1.Button, { disabled: isSelectingYear || prevMonth.isBefore(fromDate, 'month'), onClick: () => setCurrentMonth(prevMonth), size: "s", square: true, className: "smarthr-ui-Calendar-monthButtonPrev" },
                    react_1.default.createElement(Icon_1.FaChevronLeftIcon, { alt: "\u524D\u306E\u6708\u3078" })),
                react_1.default.createElement(Button_1.Button, { disabled: isSelectingYear || nextMonth.isAfter(toDate, 'month'), onClick: () => setCurrentMonth(nextMonth), size: "s", square: true, className: "smarthr-ui-Calendar-monthButtonNext" },
                    react_1.default.createElement(Icon_1.FaChevronRightIcon, { alt: "\u6B21\u306E\u6708\u3078" })))),
        react_1.default.createElement("div", { className: tableLayoutStyle },
            react_1.default.createElement(YearPicker_1.YearPicker, { fromYear: fromDate.year(), toYear: toDate.year(), selectedYear: value?.getFullYear(), onSelectYear: (year) => {
                    setCurrentMonth(currentMonth.year(year));
                    setIsSelectingYear(false);
                }, isDisplayed: isSelectingYear, id: yearPickerId }),
            react_1.default.createElement(CalendarTable_1.CalendarTable, { current: currentMonth.toDate(), from: fromDate.toDate(), to: toDate.toDate(), onSelectDate: onSelectDate, selected: isValidValue ? value : null }))));
});
//# sourceMappingURL=Calendar.js.map