import React, { ComponentPropsWithoutRef, MouseEvent, ReactNode } from 'react';
import { Input } from '../Input';
import { BaseProps, ComboBoxItem } from './types';
import type { DecoratorsType } from '../../types';
type Props<T> = BaseProps<T> & {
    /**
     * 選択されているアイテム
     */
    selectedItem: ComboBoxItem<T> | null;
    /**
     * デフォルトで選択されるアイテム
     */
    defaultItem?: ComboBoxItem<T>;
    /**
     * コンポーネント内の先頭に表示する内容
     */
    prefix?: ReactNode;
    /**
     * 選択されているアイテムがクリアされた時に発火するコールバック関数
     */
    onClear?: () => void;
    /**
     * 選択されているアイテムがクリアされた時に発火するコールバック関数
     * 指定している場合、クリア時にonClickを実行せずにonClearClickのみ実行する
     */
    onClearClick?: (e: MouseEvent) => void;
    /**
     * 選択されているアイテムのリストが変わった時に発火するコールバック関数
     */
    onChangeSelected?: (selectedItem: ComboBoxItem<T> | null) => void;
    /**
     * コンポーネントがフォーカスされたときに発火するコールバック関数
     */
    onFocus?: () => void;
    /**
     * コンポーネントからフォーカスが外れた時に発火するコールバック関数
     */
    onBlur?: () => void;
    /**
     * コンポーネント内のテキストを変更する関数/
     */
    decorators?: DecoratorsType<'noResultText'> & {
        destroyButtonIconAlt?: (text: string) => string;
    };
    /**
     * input 要素の属性
     */
    inputAttributes?: Omit<React.ComponentProps<typeof Input>, 'aria-activedescendant' | 'aria-autocomplete' | 'autoComplete' | 'className' | 'disabled' | 'required' | 'error' | 'name' | 'onChange' | 'onClick' | 'onCompositionEnd' | 'onCompositionStart' | 'onFocus' | 'onKeyDown' | 'placeholder' | 'prefix' | 'ref' | 'suffix' | 'type' | 'value'>;
};
type ElementProps = Omit<ComponentPropsWithoutRef<'div'>, keyof Props<unknown>>;
export declare const SingleComboBox: <T>(props: BaseProps<T> & {
    /**
     * 選択されているアイテム
     */
    selectedItem: ComboBoxItem<T> | null;
    /**
     * デフォルトで選択されるアイテム
     */
    defaultItem?: ComboBoxItem<T> | undefined;
    /**
     * コンポーネント内の先頭に表示する内容
     */
    prefix?: ReactNode;
    /**
     * 選択されているアイテムがクリアされた時に発火するコールバック関数
     */
    onClear?: (() => void) | undefined;
    /**
     * 選択されているアイテムがクリアされた時に発火するコールバック関数
     * 指定している場合、クリア時にonClickを実行せずにonClearClickのみ実行する
     */
    onClearClick?: ((e: MouseEvent) => void) | undefined;
    /**
     * 選択されているアイテムのリストが変わった時に発火するコールバック関数
     */
    onChangeSelected?: ((selectedItem: ComboBoxItem<T> | null) => void) | undefined;
    /**
     * コンポーネントがフォーカスされたときに発火するコールバック関数
     */
    onFocus?: (() => void) | undefined;
    /**
     * コンポーネントからフォーカスが外れた時に発火するコールバック関数
     */
    onBlur?: (() => void) | undefined;
    /**
     * コンポーネント内のテキストを変更する関数/
     */
    decorators?: (DecoratorsType<"noResultText"> & {
        destroyButtonIconAlt?: ((text: string) => string) | undefined;
    }) | undefined;
    /**
     * input 要素の属性
     */
    inputAttributes?: Omit<Omit<{
        type?: string | undefined;
        error?: boolean | undefined;
        width?: string | number | undefined;
        autoFocus?: boolean | undefined;
        prefix?: React.ReactNode;
        suffix?: React.ReactNode;
        bgColor?: "COLUMN" | "BASE_GREY" | "OVER_BACKGROUND" | "HEAD" | "BORDER" | "ACTION_BACKGROUND" | "BACKGRUOND" | undefined;
        placeholder?: string | undefined;
    } & {
        max?: string | number | undefined;
        required?: boolean | undefined;
        key?: React.Key | null | undefined;
        id?: string | undefined;
        height?: string | number | undefined;
        name?: string | undefined;
        min?: string | number | undefined;
        color?: string | undefined;
        content?: string | undefined;
        translate?: "yes" | "no" | undefined;
        value?: string | number | readonly string[] | undefined;
        hidden?: boolean | undefined;
        form?: string | undefined;
        slot?: string | undefined;
        style?: React.CSSProperties | undefined;
        title?: string | undefined;
        dir?: string | undefined;
        pattern?: string | undefined;
        rel?: string | undefined;
        accessKey?: string | undefined;
        draggable?: (boolean | "false" | "true") | undefined;
        lang?: string | undefined;
        className?: string | undefined;
        role?: React.AriaRole | undefined;
        children?: React.ReactNode;
        contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
        enterKeyHint?: "search" | "next" | "done" | "enter" | "go" | "previous" | "send" | undefined;
        inputMode?: "search" | "numeric" | "none" | "url" | "text" | "email" | "tel" | "decimal" | undefined;
        nonce?: string | undefined;
        tabIndex?: number | undefined;
        disabled?: boolean | undefined;
        multiple?: boolean | undefined;
        size?: number | undefined;
        ref?: ((instance: HTMLInputElement | null) => void) | React.RefObject<HTMLInputElement> | null | undefined;
        suppressHydrationWarning?: boolean | undefined;
        "aria-activedescendant"?: string | undefined;
        "aria-atomic"?: (boolean | "false" | "true") | undefined;
        "aria-autocomplete"?: "inline" | "both" | "none" | "list" | undefined;
        "aria-braillelabel"?: string | undefined;
        "aria-brailleroledescription"?: string | undefined;
        "aria-busy"?: (boolean | "false" | "true") | undefined;
        "aria-checked"?: boolean | "false" | "mixed" | "true" | undefined;
        "aria-colcount"?: number | undefined;
        "aria-colindex"?: number | undefined;
        "aria-colindextext"?: string | undefined;
        "aria-colspan"?: number | undefined;
        "aria-controls"?: string | undefined;
        "aria-current"?: boolean | "false" | "time" | "location" | "page" | "true" | "step" | "date" | undefined;
        "aria-describedby"?: string | undefined;
        "aria-description"?: string | undefined;
        "aria-details"?: string | undefined;
        "aria-disabled"?: (boolean | "false" | "true") | undefined;
        "aria-dropeffect"?: "link" | "none" | "copy" | "move" | "execute" | "popup" | undefined;
        "aria-errormessage"?: string | undefined;
        "aria-expanded"?: (boolean | "false" | "true") | undefined;
        "aria-flowto"?: string | undefined;
        "aria-grabbed"?: (boolean | "false" | "true") | undefined;
        "aria-haspopup"?: boolean | "false" | "grid" | "dialog" | "menu" | "listbox" | "true" | "tree" | undefined;
        "aria-hidden"?: (boolean | "false" | "true") | undefined;
        "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
        "aria-keyshortcuts"?: string | undefined;
        "aria-label"?: string | undefined;
        "aria-labelledby"?: string | undefined;
        "aria-level"?: number | undefined;
        "aria-live"?: "off" | "assertive" | "polite" | undefined;
        "aria-modal"?: (boolean | "false" | "true") | undefined;
        "aria-multiline"?: (boolean | "false" | "true") | undefined;
        "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
        "aria-orientation"?: "horizontal" | "vertical" | undefined;
        "aria-owns"?: string | undefined;
        "aria-placeholder"?: string | undefined;
        "aria-posinset"?: number | undefined;
        "aria-pressed"?: boolean | "false" | "mixed" | "true" | undefined;
        "aria-readonly"?: (boolean | "false" | "true") | undefined;
        "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
        "aria-required"?: (boolean | "false" | "true") | undefined;
        "aria-roledescription"?: string | undefined;
        "aria-rowcount"?: number | undefined;
        "aria-rowindex"?: number | undefined;
        "aria-rowindextext"?: string | undefined;
        "aria-rowspan"?: number | undefined;
        "aria-selected"?: (boolean | "false" | "true") | undefined;
        "aria-setsize"?: number | undefined;
        "aria-sort"?: "none" | "other" | "ascending" | "descending" | undefined;
        "aria-valuemax"?: number | undefined;
        "aria-valuemin"?: number | undefined;
        "aria-valuenow"?: number | undefined;
        "aria-valuetext"?: string | undefined;
        dangerouslySetInnerHTML?: {
            __html: string | TrustedHTML;
        } | undefined;
        onCopy?: React.ClipboardEventHandler<HTMLInputElement> | undefined;
        onCopyCapture?: React.ClipboardEventHandler<HTMLInputElement> | undefined;
        onCut?: React.ClipboardEventHandler<HTMLInputElement> | undefined;
        onCutCapture?: React.ClipboardEventHandler<HTMLInputElement> | undefined;
        onPaste?: React.ClipboardEventHandler<HTMLInputElement> | undefined;
        onPasteCapture?: React.ClipboardEventHandler<HTMLInputElement> | undefined;
        onCompositionEnd?: React.CompositionEventHandler<HTMLInputElement> | undefined;
        onCompositionEndCapture?: React.CompositionEventHandler<HTMLInputElement> | undefined;
        onCompositionStart?: React.CompositionEventHandler<HTMLInputElement> | undefined;
        onCompositionStartCapture?: React.CompositionEventHandler<HTMLInputElement> | undefined;
        onCompositionUpdate?: React.CompositionEventHandler<HTMLInputElement> | undefined;
        onCompositionUpdateCapture?: React.CompositionEventHandler<HTMLInputElement> | undefined;
        onFocus?: React.FocusEventHandler<HTMLInputElement> | undefined;
        onFocusCapture?: React.FocusEventHandler<HTMLInputElement> | undefined;
        onBlur?: React.FocusEventHandler<HTMLInputElement> | undefined;
        onBlurCapture?: React.FocusEventHandler<HTMLInputElement> | undefined;
        onChange?: React.ChangeEventHandler<HTMLInputElement> | undefined;
        onChangeCapture?: React.FormEventHandler<HTMLInputElement> | undefined;
        onBeforeInput?: React.FormEventHandler<HTMLInputElement> | undefined;
        onBeforeInputCapture?: React.FormEventHandler<HTMLInputElement> | undefined;
        onInput?: React.FormEventHandler<HTMLInputElement> | undefined;
        onInputCapture?: React.FormEventHandler<HTMLInputElement> | undefined;
        onReset?: React.FormEventHandler<HTMLInputElement> | undefined;
        onResetCapture?: React.FormEventHandler<HTMLInputElement> | undefined;
        onSubmit?: React.FormEventHandler<HTMLInputElement> | undefined;
        onSubmitCapture?: React.FormEventHandler<HTMLInputElement> | undefined;
        onInvalid?: React.FormEventHandler<HTMLInputElement> | undefined;
        onInvalidCapture?: React.FormEventHandler<HTMLInputElement> | undefined;
        onLoad?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onLoadCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onError?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onErrorCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onKeyDown?: React.KeyboardEventHandler<HTMLInputElement> | undefined;
        onKeyDownCapture?: React.KeyboardEventHandler<HTMLInputElement> | undefined;
        onKeyPress?: React.KeyboardEventHandler<HTMLInputElement> | undefined;
        onKeyPressCapture?: React.KeyboardEventHandler<HTMLInputElement> | undefined;
        onKeyUp?: React.KeyboardEventHandler<HTMLInputElement> | undefined;
        onKeyUpCapture?: React.KeyboardEventHandler<HTMLInputElement> | undefined;
        onAbort?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onAbortCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onCanPlay?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onCanPlayCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onCanPlayThrough?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onCanPlayThroughCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onDurationChange?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onDurationChangeCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onEmptied?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onEmptiedCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onEncrypted?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onEncryptedCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onEnded?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onEndedCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onLoadedData?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onLoadedDataCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onLoadedMetadata?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onLoadedMetadataCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onLoadStart?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onLoadStartCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onPause?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onPauseCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onPlay?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onPlayCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onPlaying?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onPlayingCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onProgress?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onProgressCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onRateChange?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onRateChangeCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onResize?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onResizeCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onSeeked?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onSeekedCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onSeeking?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onSeekingCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onStalled?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onStalledCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onSuspend?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onSuspendCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onTimeUpdate?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onTimeUpdateCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onVolumeChange?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onVolumeChangeCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onWaiting?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onWaitingCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onAuxClick?: React.MouseEventHandler<HTMLInputElement> | undefined;
        onAuxClickCapture?: React.MouseEventHandler<HTMLInputElement> | undefined;
        onClick?: React.MouseEventHandler<HTMLInputElement> | undefined;
        onClickCapture?: React.MouseEventHandler<HTMLInputElement> | undefined;
        onContextMenu?: React.MouseEventHandler<HTMLInputElement> | undefined;
        onContextMenuCapture?: React.MouseEventHandler<HTMLInputElement> | undefined;
        onDoubleClick?: React.MouseEventHandler<HTMLInputElement> | undefined;
        onDoubleClickCapture?: React.MouseEventHandler<HTMLInputElement> | undefined;
        onDrag?: React.DragEventHandler<HTMLInputElement> | undefined;
        onDragCapture?: React.DragEventHandler<HTMLInputElement> | undefined;
        onDragEnd?: React.DragEventHandler<HTMLInputElement> | undefined;
        onDragEndCapture?: React.DragEventHandler<HTMLInputElement> | undefined;
        onDragEnter?: React.DragEventHandler<HTMLInputElement> | undefined;
        onDragEnterCapture?: React.DragEventHandler<HTMLInputElement> | undefined;
        onDragExit?: React.DragEventHandler<HTMLInputElement> | undefined;
        onDragExitCapture?: React.DragEventHandler<HTMLInputElement> | undefined;
        onDragLeave?: React.DragEventHandler<HTMLInputElement> | undefined;
        onDragLeaveCapture?: React.DragEventHandler<HTMLInputElement> | undefined;
        onDragOver?: React.DragEventHandler<HTMLInputElement> | undefined;
        onDragOverCapture?: React.DragEventHandler<HTMLInputElement> | undefined;
        onDragStart?: React.DragEventHandler<HTMLInputElement> | undefined;
        onDragStartCapture?: React.DragEventHandler<HTMLInputElement> | undefined;
        onDrop?: React.DragEventHandler<HTMLInputElement> | undefined;
        onDropCapture?: React.DragEventHandler<HTMLInputElement> | undefined;
        onMouseDown?: React.MouseEventHandler<HTMLInputElement> | undefined;
        onMouseDownCapture?: React.MouseEventHandler<HTMLInputElement> | undefined;
        onMouseEnter?: React.MouseEventHandler<HTMLInputElement> | undefined;
        onMouseLeave?: React.MouseEventHandler<HTMLInputElement> | undefined;
        onMouseMove?: React.MouseEventHandler<HTMLInputElement> | undefined;
        onMouseMoveCapture?: React.MouseEventHandler<HTMLInputElement> | undefined;
        onMouseOut?: React.MouseEventHandler<HTMLInputElement> | undefined;
        onMouseOutCapture?: React.MouseEventHandler<HTMLInputElement> | undefined;
        onMouseOver?: React.MouseEventHandler<HTMLInputElement> | undefined;
        onMouseOverCapture?: React.MouseEventHandler<HTMLInputElement> | undefined;
        onMouseUp?: React.MouseEventHandler<HTMLInputElement> | undefined;
        onMouseUpCapture?: React.MouseEventHandler<HTMLInputElement> | undefined;
        onSelect?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onSelectCapture?: React.ReactEventHandler<HTMLInputElement> | undefined;
        onTouchCancel?: React.TouchEventHandler<HTMLInputElement> | undefined;
        onTouchCancelCapture?: React.TouchEventHandler<HTMLInputElement> | undefined;
        onTouchEnd?: React.TouchEventHandler<HTMLInputElement> | undefined;
        onTouchEndCapture?: React.TouchEventHandler<HTMLInputElement> | undefined;
        onTouchMove?: React.TouchEventHandler<HTMLInputElement> | undefined;
        onTouchMoveCapture?: React.TouchEventHandler<HTMLInputElement> | undefined;
        onTouchStart?: React.TouchEventHandler<HTMLInputElement> | undefined;
        onTouchStartCapture?: React.TouchEventHandler<HTMLInputElement> | undefined;
        onPointerDown?: React.PointerEventHandler<HTMLInputElement> | undefined;
        onPointerDownCapture?: React.PointerEventHandler<HTMLInputElement> | undefined;
        onPointerMove?: React.PointerEventHandler<HTMLInputElement> | undefined;
        onPointerMoveCapture?: React.PointerEventHandler<HTMLInputElement> | undefined;
        onPointerUp?: React.PointerEventHandler<HTMLInputElement> | undefined;
        onPointerUpCapture?: React.PointerEventHandler<HTMLInputElement> | undefined;
        onPointerCancel?: React.PointerEventHandler<HTMLInputElement> | undefined;
        onPointerCancelCapture?: React.PointerEventHandler<HTMLInputElement> | undefined;
        onPointerEnter?: React.PointerEventHandler<HTMLInputElement> | undefined;
        onPointerLeave?: React.PointerEventHandler<HTMLInputElement> | undefined;
        onPointerOver?: React.PointerEventHandler<HTMLInputElement> | undefined;
        onPointerOverCapture?: React.PointerEventHandler<HTMLInputElement> | undefined;
        onPointerOut?: React.PointerEventHandler<HTMLInputElement> | undefined;
        onPointerOutCapture?: React.PointerEventHandler<HTMLInputElement> | undefined;
        onGotPointerCapture?: React.PointerEventHandler<HTMLInputElement> | undefined;
        onGotPointerCaptureCapture?: React.PointerEventHandler<HTMLInputElement> | undefined;
        onLostPointerCapture?: React.PointerEventHandler<HTMLInputElement> | undefined;
        onLostPointerCaptureCapture?: React.PointerEventHandler<HTMLInputElement> | undefined;
        onScroll?: React.UIEventHandler<HTMLInputElement> | undefined;
        onScrollCapture?: React.UIEventHandler<HTMLInputElement> | undefined;
        onWheel?: React.WheelEventHandler<HTMLInputElement> | undefined;
        onWheelCapture?: React.WheelEventHandler<HTMLInputElement> | undefined;
        onAnimationStart?: React.AnimationEventHandler<HTMLInputElement> | undefined;
        onAnimationStartCapture?: React.AnimationEventHandler<HTMLInputElement> | undefined;
        onAnimationEnd?: React.AnimationEventHandler<HTMLInputElement> | undefined;
        onAnimationEndCapture?: React.AnimationEventHandler<HTMLInputElement> | undefined;
        onAnimationIteration?: React.AnimationEventHandler<HTMLInputElement> | undefined;
        onAnimationIterationCapture?: React.AnimationEventHandler<HTMLInputElement> | undefined;
        onTransitionEnd?: React.TransitionEventHandler<HTMLInputElement> | undefined;
        onTransitionEndCapture?: React.TransitionEventHandler<HTMLInputElement> | undefined;
        defaultChecked?: boolean | undefined;
        defaultValue?: string | number | readonly string[] | undefined;
        suppressContentEditableWarning?: boolean | undefined;
        contextMenu?: string | undefined;
        spellCheck?: (boolean | "false" | "true") | undefined;
        radioGroup?: string | undefined;
        about?: string | undefined;
        datatype?: string | undefined;
        inlist?: any;
        property?: string | undefined;
        resource?: string | undefined;
        rev?: string | undefined;
        typeof?: string | undefined;
        vocab?: string | undefined;
        autoCapitalize?: string | undefined;
        autoCorrect?: string | undefined;
        autoSave?: string | undefined;
        itemProp?: string | undefined;
        itemScope?: boolean | undefined;
        itemType?: string | undefined;
        itemID?: string | undefined;
        itemRef?: string | undefined;
        results?: number | undefined;
        security?: string | undefined;
        unselectable?: "off" | "on" | undefined;
        is?: string | undefined;
        accept?: string | undefined;
        alt?: string | undefined;
        autoComplete?: React.HTMLInputAutoCompleteAttribute | undefined;
        capture?: boolean | "environment" | "user" | undefined;
        checked?: boolean | undefined;
        formAction?: string | undefined;
        formEncType?: string | undefined;
        formMethod?: string | undefined;
        formNoValidate?: boolean | undefined;
        formTarget?: string | undefined;
        list?: string | undefined;
        maxLength?: number | undefined;
        minLength?: number | undefined;
        readOnly?: boolean | undefined;
        src?: string | undefined;
        step?: string | number | undefined;
    }, "ref"> & React.RefAttributes<HTMLInputElement>, "required" | "type" | "error" | "name" | "value" | "className" | "prefix" | "disabled" | "ref" | "aria-activedescendant" | "aria-autocomplete" | "onCompositionEnd" | "onCompositionStart" | "onFocus" | "onChange" | "onKeyDown" | "onClick" | "autoComplete" | "placeholder" | "suffix"> | undefined;
} & ElementProps & React.RefAttributes<HTMLInputElement>) => React.ReactNode;
export {};
