"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DatePicker = exports.DEFAULT_FROM = void 0;
const dayjs_1 = __importDefault(require("dayjs"));
const react_1 = __importStar(require("react"));
const tailwind_variants_1 = require("tailwind-variants");
const useId_1 = require("../../hooks/useId");
const useOuterClick_1 = require("../../hooks/useOuterClick");
const useTailwindTheme_1 = require("../../hooks/useTailwindTheme");
const Calendar_1 = require("../Calendar");
const Icon_1 = require("../Icon");
const Input_1 = require("../Input");
const Portal_1 = require("./Portal");
const datePickerHelper_1 = require("./datePickerHelper");
const useGlobalKeyDown_1 = require("./useGlobalKeyDown");
exports.DEFAULT_FROM = new Date(1900, 0, 1);
const datePicker = (0, tailwind_variants_1.tv)({
    slots: {
        container: 'smarthr-ui-DatePicker shr-inline-block',
        inputSuffixLayout: 'shr-box-border shr-h-full shr-py-0.5',
        inputSuffixWrapper: 'shr-border-l-shorthand shr-box-border shr-flex shr-h-full shr-items-center shr-justify-center shr-ps-0.5 shr-text-base',
        inputSuffixText: 'shr-text-gray shr-me-0.5 shr-text-sm',
    },
});
exports.DatePicker = (0, react_1.forwardRef)(({ value, name, from = exports.DEFAULT_FROM, to, disabled, width, error, className, parseInput, formatDate, showAlternative, onChangeDate, ...inputAttrs }, ref) => {
    const { containerStyleProps, inputSuffixLayoutStyle, inputSuffixWrapperStyle, inputSuffixTextStyle, } = (0, react_1.useMemo)(() => {
        const { container, inputSuffixLayout, inputSuffixWrapper, inputSuffixText } = datePicker();
        return {
            containerStyleProps: {
                className: container({ className }),
                style: {
                    width: typeof width === 'number' ? `${width}px` : width,
                },
            },
            inputSuffixLayoutStyle: inputSuffixLayout(),
            inputSuffixWrapperStyle: inputSuffixWrapper(),
            inputSuffixTextStyle: inputSuffixText(),
        };
    }, [className, width]);
    const stringToDate = (0, react_1.useCallback)((str) => {
        if (!str) {
            return null;
        }
        return parseInput ? parseInput(str) : (0, datePickerHelper_1.parseJpnDateString)(str);
    }, [parseInput]);
    const dateToString = (0, react_1.useCallback)((d) => {
        if (formatDate) {
            return formatDate(d);
        }
        if (!d) {
            return '';
        }
        return (0, dayjs_1.default)(d).format('YYYY/MM/DD');
    }, [formatDate]);
    const dateToAlternativeFormat = (0, react_1.useCallback)((d) => {
        if (!d || !showAlternative) {
            return null;
        }
        return showAlternative(d);
    }, [showAlternative]);
    const { textColor } = (0, useTailwindTheme_1.useTheme)();
    const [selectedDate, setSelectedDate] = (0, react_1.useState)(stringToDate(value));
    const inputRef = (0, react_1.useRef)(null);
    const inputWrapperRef = (0, react_1.useRef)(null);
    const calendarPortalRef = (0, react_1.useRef)(null);
    const [inputRect, setInputRect] = (0, react_1.useState)(null);
    const [isInputFocused, setIsInputFocused] = (0, react_1.useState)(false);
    const [isCalendarShown, setIsCalendarShown] = (0, react_1.useState)(false);
    const [alternativeFormat, setAlternativeFormat] = (0, react_1.useState)(null);
    const calenderId = (0, useId_1.useId)();
    (0, react_1.useImperativeHandle)(ref, () => inputRef.current);
    const updateDate = (0, react_1.useCallback)((newDate) => {
        if (!inputRef.current ||
            newDate === selectedDate ||
            (newDate && selectedDate && newDate.getTime() === selectedDate.getTime())) {
            // Do not update date if the new date is same with the old one.
            return;
        }
        const isValid = !newDate || (0, dayjs_1.default)(newDate).isValid();
        const nextDate = isValid ? newDate : null;
        const errors = [];
        if (!isValid) {
            errors.push('INVALID_DATE');
        }
        inputRef.current.value = dateToString(nextDate);
        setAlternativeFormat(dateToAlternativeFormat(nextDate));
        setSelectedDate(nextDate);
        onChangeDate && onChangeDate(nextDate, inputRef.current.value, { errors });
    }, [selectedDate, dateToString, dateToAlternativeFormat, onChangeDate]);
    const switchCalendarVisibility = (0, react_1.useCallback)((isVisible) => {
        if (!isVisible) {
            setIsCalendarShown(false);
            return;
        }
        if (!inputWrapperRef.current) {
            return;
        }
        setIsCalendarShown(true);
        setInputRect(inputWrapperRef.current.getBoundingClientRect());
    }, []);
    (0, react_1.useEffect)(() => {
        if (value === undefined || !inputRef.current) {
            return;
        }
        /**
         * Do not format the given value in the following cases
         * - while input element is focused.
         * - if the given value is not date formattable.
         */
        if (!isInputFocused) {
            const newDate = stringToDate(value);
            if (newDate && (0, dayjs_1.default)(newDate).isValid()) {
                inputRef.current.value = dateToString(newDate);
                setAlternativeFormat(dateToAlternativeFormat(newDate));
                setSelectedDate(newDate);
                return;
            }
            setSelectedDate(null);
        }
        inputRef.current.value = value || '';
    }, [value, isInputFocused, dateToString, dateToAlternativeFormat, stringToDate]);
    (0, useOuterClick_1.useOuterClick)([inputWrapperRef, calendarPortalRef], (0, react_1.useCallback)(() => {
        switchCalendarVisibility(false);
    }, [switchCalendarVisibility]));
    const handleKeyDown = (0, react_1.useCallback)((e) => {
        if (e.key !== 'Tab' || !inputRef.current || !calendarPortalRef.current) {
            return;
        }
        const calendarButtons = calendarPortalRef.current.querySelectorAll('button');
        if (calendarButtons.length === 0) {
            return;
        }
        const firstCalendarButton = calendarButtons[0];
        const lastCalendarButton = calendarButtons[calendarButtons.length - 1];
        if (isInputFocused) {
            if (e.shiftKey) {
                // move focus from Input to previous elements of DatePicker
                switchCalendarVisibility(false);
                return;
            }
            // move focus from Input to Calendar
            e.preventDefault();
            firstCalendarButton.focus();
            return;
        }
        const currentFocused = Array.from(calendarButtons).find((button) => button === e.target);
        if (e.shiftKey && currentFocused === firstCalendarButton) {
            // move focus from Calendar to Input
            inputRef.current.focus();
            e.preventDefault();
        }
        else if (!e.shiftKey && currentFocused === lastCalendarButton) {
            // move focus from Calendar to next elements of DatePicker
            inputRef.current.focus();
            switchCalendarVisibility(false);
        }
    }, [isInputFocused, switchCalendarVisibility]);
    (0, useGlobalKeyDown_1.useGlobalKeyDown)(handleKeyDown);
    const caretIconColor = (0, react_1.useMemo)(() => {
        if (isInputFocused || isCalendarShown)
            return textColor.black;
        if (disabled)
            return textColor.disabled;
        return textColor.grey;
    }, [
        isInputFocused,
        isCalendarShown,
        textColor.black,
        textColor.disabled,
        textColor.grey,
        disabled,
    ]);
    return (react_1.default.createElement("div", { ...containerStyleProps, onClick: () => {
            if (!disabled && !isCalendarShown) {
                switchCalendarVisibility(true);
            }
        }, onKeyDown: (e) => {
            if ((e.key === 'Escape' || e.key === 'Esc') && isCalendarShown) {
                e.stopPropagation();
                requestAnimationFrame(() => {
                    // delay hiding calendar because calendar will be displayed when input is focused
                    switchCalendarVisibility(false);
                });
                inputRef.current && inputRef.current.focus();
            }
        }, role: "presentation" },
        react_1.default.createElement("div", { ref: inputWrapperRef },
            react_1.default.createElement(Input_1.Input, { ...inputAttrs, width: "100%", name: name, onChange: () => {
                    if (isCalendarShown) {
                        switchCalendarVisibility(false);
                    }
                }, onKeyPress: ({ key, currentTarget: { value: inputString } }) => {
                    if (key === 'Enter') {
                        switchCalendarVisibility(!isCalendarShown);
                        const newDate = stringToDate(inputString);
                        updateDate(newDate);
                    }
                }, onFocus: () => {
                    setIsInputFocused(true);
                    switchCalendarVisibility(true);
                }, onBlur: ({ target: { value: inputString } }) => {
                    setIsInputFocused(false);
                    if (inputString === '') {
                        updateDate(null);
                        return;
                    }
                    const newDate = stringToDate(inputString);
                    updateDate(newDate);
                }, suffix: react_1.default.createElement("span", { className: inputSuffixLayoutStyle },
                    react_1.default.createElement("span", { className: inputSuffixWrapperStyle },
                        showAlternative && (react_1.default.createElement("span", { className: inputSuffixTextStyle }, alternativeFormat)),
                        react_1.default.createElement(Icon_1.FaCalendarAltIcon, { color: caretIconColor }))), disabled: disabled, error: error, ref: inputRef, className: "smarthr-ui-DatePicker-inputContainer", "aria-expanded": isCalendarShown, "aria-controls": calenderId, "aria-haspopup": true })),
        isCalendarShown && inputRect && (react_1.default.createElement(Portal_1.Portal, { inputRect: inputRect, ref: calendarPortalRef },
            react_1.default.createElement(Calendar_1.Calendar, { id: calenderId, value: selectedDate || undefined, from: from, to: to, onSelectDate: (_, selected) => {
                    updateDate(selected);
                    requestAnimationFrame(() => {
                        // delay hiding calendar because calendar will be displayed when input is focused
                        switchCalendarVisibility(false);
                    });
                    inputRef.current && inputRef.current.focus();
                } })))));
});
//# sourceMappingURL=DatePicker.js.map