import { FC, FormEvent, PropsWithChildren, ReactNode } from 'react';
import { HeadingTagTypes } from '../../Heading';
import type { DecoratorsType, ResponseMessageType } from '../../../types';
export type BaseProps = PropsWithChildren<{
    /**
     * ダイアログのタイトル
     */
    title: ReactNode;
    /**
     * ダイアログのサブタイトル
     */
    subtitle?: ReactNode;
    /**
     * @deprecated SectioningContent(Article, Aside, Nav, Section)でDialog全体をラップして、ダイアログタイトルのHeadingレベルを設定してください
     */
    titleTag?: HeadingTagTypes;
    /**
     * アクションボタンのラベル
     */
    actionText: ReactNode;
    /**
     * アクションボタンのスタイル
     */
    actionTheme?: 'primary' | 'secondary' | 'danger';
    /**
     * アクションボタンをクリックした時に発火するコールバック関数
     * @param closeDialog - ダイアログを閉じる関数
     */
    onSubmit: (closeDialog: () => void, e: FormEvent<HTMLFormElement>) => void;
    /**
     * アクションボタンを無効にするかどうか
     */
    actionDisabled?: boolean;
    /**
     * 閉じるボタンを無効にするかどうか
     */
    closeDisabled?: boolean;
    /** ダイアログフッターの左端操作領域 */
    subActionArea?: ReactNode;
    /** コンポーネント内の文言を変更するための関数を設定 */
    decorators?: DecoratorsType<'closeButtonLabel'>;
}>;
export type FormDialogContentInnerProps = BaseProps & {
    onClickClose: () => void;
    responseMessage?: ResponseMessageType;
    titleId: string;
};
export declare const FormDialogContentInner: FC<FormDialogContentInnerProps>;
