"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModelessDialog = void 0;
const react_1 = __importStar(require("react"));
const react_draggable_1 = __importDefault(require("react-draggable"));
const tailwind_variants_1 = require("tailwind-variants");
const useHandleEscape_1 = require("../../hooks/useHandleEscape");
const useId_1 = require("../../hooks/useId");
const useTailwindTheme_1 = require("../../hooks/useTailwindTheme");
const Base_1 = require("../Base");
const Button_1 = require("../Button");
const Icon_1 = require("../Icon");
const DialogOverlap_1 = require("./DialogOverlap");
const useDialogPortal_1 = require("./useDialogPortal");
const DIALOG_HANDLER_ARIA_LABEL = 'ダイアログの位置';
const CLOSE_BUTTON_ICON_ALT = '閉じる';
const modelessDialog = (0, tailwind_variants_1.tv)({
    slots: {
        layout: 'smarthr-ui-ModelessDialog shr-fixed',
        box: 'smarthr-ui-ModelessDialog-box shr-flex shr-h-full shr-max-h-full shr-flex-col',
        headerEl: 'smarthr-ui-ModelessDialog-header shr-border-b-shorthand shr-relative shr-flex shr-cursor-move shr-items-center shr-rounded-tl-l shr-rounded-tr-l shr-pe-1 shr-ps-1.5 hover:shr-bg-white-darken',
        dialogHandler: [
            'smarthr-ui-ModelessDialog-handle shr-absolute shr-inset-x-0 shr-bottom-0 shr-top-[2px] shr-m-auto shr-flex shr-justify-center shr-rounded-tl-s shr-rounded-tr-s shr-text-grey shr-transition-colors shr-duration-100 shr-ease-in-out',
            'focus-visible:shr-bg-white-darken focus-visible:shr-shadow-outline focus-visible:shr-outline-none',
        ],
        title: [
            'shr-relative' /* DialogHandlerの上に出すためにスタッキングコンテキストを生成 */,
            'shr-my-1 shr-me-1',
        ],
        closeButtonLayout: [
            'shr-relative' /* DialogHandlerの上に出すためにスタッキングコンテキストを生成 */,
            'shr-ml-auto shr-shrink-0',
        ],
        content: 'smarthr-ui-ModelessDialog-content shr-flex-1 shr-overflow-auto shr-overscroll-contain',
        footerEl: 'smarthr-ui-ModelessDialog-footer shr-border-t-shorthand',
    },
});
const ModelessDialog = ({ header, children, footer, isOpen, onClickClose, onPressEscape, width, height, top, left, right, bottom, portalParent, className, decorators, id, ...props }) => {
    const labelId = (0, useId_1.useId)();
    const { createPortal } = (0, useDialogPortal_1.useDialogPortal)(portalParent, id);
    const { spacing } = (0, useTailwindTheme_1.useTheme)();
    const { layoutStyle, boxStyle, headerStyle, titleStyle, dialogHandlerStyle, closeButtonLayoutStyle, contentStyle, footerStyle, } = (0, react_1.useMemo)(() => {
        const { layout, box, headerEl, title, dialogHandler, closeButtonLayout, content, footerEl } = modelessDialog();
        return {
            layoutStyle: layout({ className }),
            boxStyle: box(),
            headerStyle: headerEl(),
            titleStyle: title(),
            dialogHandlerStyle: dialogHandler(),
            closeButtonLayoutStyle: closeButtonLayout(),
            contentStyle: content(),
            footerStyle: footerEl(),
        };
    }, [className]);
    const boxStyleProps = (0, react_1.useMemo)(() => {
        const leftMargin = typeof left === 'number' ? `${left}px` : left;
        const rightMargin = typeof right === 'number' ? `${right}px` : right;
        /* TODO: 幅の定数指定は、トークンが決まり theme に入ったら差し替える */
        const style = width === undefined
            ? {
                maxWidth: `min(calc(100vw - max(${leftMargin || 0}, ${spacing[0.5]}) - max(${rightMargin || 0}, ${spacing[0.5]})), 800px)`,
            }
            : undefined;
        return {
            className: boxStyle,
            style,
        };
    }, [boxStyle, left, right, spacing, width]);
    const wrapperRef = (0, react_1.useRef)(null);
    const focusTargetRef = (0, react_1.useRef)(null);
    const [wrapperPosition, setWrapperPosition] = (0, react_1.useState)(undefined);
    const [centering, setCentering] = (0, react_1.useState)({});
    const [position, setPosition] = (0, react_1.useState)({
        x: 0,
        y: 0,
    });
    const [draggableBounds, setDraggableBounds] = (0, react_1.useState)();
    const dialogHandlerAriaLabel = (0, react_1.useMemo)(() => decorators?.dialogHandlerAriaLabel?.(DIALOG_HANDLER_ARIA_LABEL) || DIALOG_HANDLER_ARIA_LABEL, [decorators]);
    const defaultAriaValuetext = (0, react_1.useMemo)(() => wrapperPosition
        ? `上から${Math.trunc(wrapperPosition.top)}px、左から${Math.trunc(wrapperPosition.left)}px`
        : '', [wrapperPosition]);
    const dialogHandlerAriaValuetext = (0, react_1.useMemo)(() => defaultAriaValuetext
        ? decorators?.dialogHandlerAriaValuetext?.(defaultAriaValuetext, wrapperPosition) ||
            defaultAriaValuetext
        : undefined, [defaultAriaValuetext, wrapperPosition, decorators]);
    const closeButtonIconAlt = (0, react_1.useMemo)(() => decorators?.closeButtonIconAlt?.(CLOSE_BUTTON_ICON_ALT) || CLOSE_BUTTON_ICON_ALT, [decorators]);
    const topStyle = centering.top !== undefined ? centering.top : top;
    const leftStyle = centering.left !== undefined ? centering.left : left;
    const handleArrowKey = (0, react_1.useCallback)((e) => {
        if (!isOpen || document.activeElement !== e.currentTarget) {
            return;
        }
        const movingDistance = 20;
        switch (e.key) {
            case 'ArrowUp':
                setPosition((prev) => ({
                    x: prev.x,
                    y: prev.y - movingDistance,
                }));
                e.preventDefault();
                break;
            case 'ArrowDown':
                setPosition((prev) => ({
                    x: prev.x,
                    y: prev.y + movingDistance,
                }));
                e.preventDefault();
                break;
            case 'ArrowLeft':
                setPosition((prev) => ({
                    x: prev.x - movingDistance,
                    y: prev.y,
                }));
                e.preventDefault();
                break;
            case 'ArrowRight':
                setPosition((prev) => ({
                    x: prev.x + movingDistance,
                    y: prev.y,
                }));
                e.preventDefault();
                break;
        }
    }, [isOpen]);
    (0, react_1.useEffect)(() => {
        if (wrapperRef.current instanceof Element) {
            setWrapperPosition(wrapperRef.current.getBoundingClientRect());
        }
    }, [position]);
    (0, react_1.useEffect)(() => {
        // 中央寄せの座標計算を行う
        if (!wrapperRef.current || !isOpen) {
            return;
        }
        const isXCenter = left === undefined && right === undefined;
        const isYCenter = top === undefined && bottom === undefined;
        if (isXCenter || isYCenter) {
            const rect = wrapperRef.current.getBoundingClientRect();
            setCentering({
                top: isYCenter ? window.innerHeight / 2 - rect.height / 2 : undefined,
                left: isXCenter ? window.innerWidth / 2 - rect.width / 2 : undefined,
            });
        }
    }, [bottom, isOpen, left, right, top]);
    (0, react_1.useEffect)(() => {
        if (!isOpen)
            return;
        if (centering.top) {
            setDraggableBounds({ top: centering.top * -1 });
            return;
        }
        if (wrapperRef.current) {
            const rect = wrapperRef.current.getBoundingClientRect();
            setDraggableBounds({ top: rect.top * -1 });
        }
    }, [isOpen, centering.top]);
    (0, react_1.useEffect)(() => {
        if (isOpen) {
            setPosition({ x: 0, y: 0 });
            focusTargetRef.current?.focus();
        }
    }, [isOpen]);
    (0, useHandleEscape_1.useHandleEscape)((0, react_1.useCallback)(() => {
        if (isOpen) {
            onPressEscape && onPressEscape();
        }
    }, [isOpen, onPressEscape]));
    return createPortal(react_1.default.createElement(DialogOverlap_1.DialogOverlap, { isOpen: isOpen },
        react_1.default.createElement(react_draggable_1.default, { handle: ".smarthr-ui-ModelessDialog-handle", onStart: (_, data) => setPosition({ x: data.x, y: data.y }), onDrag: (_, data) => {
                setPosition((prev) => ({
                    x: prev.x + data.deltaX,
                    y: prev.y + data.deltaY,
                }));
            }, position: position, bounds: draggableBounds },
            react_1.default.createElement("div", { ...props, className: layoutStyle, style: {
                    top: topStyle,
                    left: leftStyle,
                    right,
                    bottom,
                    width,
                    height,
                }, ref: wrapperRef, role: "dialog", "aria-labelledby": labelId },
                react_1.default.createElement(Base_1.Base, { ...boxStyleProps, radius: "m", layer: 3 },
                    react_1.default.createElement("div", { tabIndex: -1, ref: focusTargetRef }),
                    react_1.default.createElement("div", { className: headerStyle },
                        react_1.default.createElement("div", { className: dialogHandlerStyle, tabIndex: 0, role: "slider", "aria-label": dialogHandlerAriaLabel, "aria-valuetext": dialogHandlerAriaValuetext, onKeyDown: handleArrowKey },
                            react_1.default.createElement(Icon_1.FaGripHorizontalIcon, null)),
                        react_1.default.createElement("div", { id: labelId, className: titleStyle }, header),
                        react_1.default.createElement("div", { className: closeButtonLayoutStyle },
                            react_1.default.createElement(Button_1.Button, { type: "button", size: "s", square: true, onClick: onClickClose, className: "smarthr-ui-ModelessDialog-closeButton" },
                                react_1.default.createElement(Icon_1.FaTimesIcon, { alt: closeButtonIconAlt })))),
                    react_1.default.createElement("div", { className: contentStyle }, children),
                    footer && react_1.default.createElement("div", { className: footerStyle }, footer))))));
};
exports.ModelessDialog = ModelessDialog;
//# sourceMappingURL=ModelessDialog.js.map