"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useRemoteTrigger = exports.TRIGGER_EVENT = void 0;
const react_1 = require("react");
exports.TRIGGER_EVENT = 'smarthr-ui:remote-dialog-trigger-dispatch';
function useRemoteTrigger({ onClickClose: orgOnClickClose, onPressEscape: orgOnPressEscape, onToggle, onOpen, onClose, id, }) {
    const [isOpen, setIsOpen] = (0, react_1.useState)(false);
    const onClickClose = (0, react_1.useCallback)(() => {
        if (orgOnClickClose) {
            return orgOnClickClose(() => {
                setIsOpen(false);
            });
        }
        setIsOpen(false);
    }, [orgOnClickClose]);
    const onPressEscape = (0, react_1.useCallback)(() => {
        if (orgOnPressEscape) {
            return orgOnPressEscape(() => {
                setIsOpen(false);
            });
        }
        setIsOpen(false);
    }, [orgOnPressEscape]);
    (0, react_1.useEffect)(() => {
        const handler = ((e) => {
            if (id === e.detail.id) {
                setIsOpen(true);
            }
        });
        document.addEventListener(exports.TRIGGER_EVENT, handler);
        return () => {
            document.removeEventListener(exports.TRIGGER_EVENT, handler);
        };
    }, [id]);
    (0, react_1.useEffect)(() => {
        if (onToggle) {
            onToggle(isOpen);
        }
        if (onOpen && isOpen) {
            onOpen();
        }
        if (onClose && !isOpen) {
            onClose();
        }
        // HINT: 再レンダリング際にhookを利用していないonToggleなどが渡されると意図せず発火してしまう場合がありえるため
        // onToggle, onOpen, onClose を depsに含めていません
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [isOpen]);
    return {
        isOpen,
        onClickClose,
        onPressEscape,
    };
}
exports.useRemoteTrigger = useRemoteTrigger;
//# sourceMappingURL=useRemoteTrigger.js.map