"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FilterDropdown = void 0;
const react_1 = __importStar(require("react"));
const react_innertext_1 = __importDefault(require("react-innertext"));
const tailwind_variants_1 = require("tailwind-variants");
const Button_1 = require("../../Button");
const Icon_1 = require("../../Icon");
const Layout_1 = require("../../Layout");
const ResponseMessage_1 = require("../../ResponseMessage");
const Dropdown_1 = require("../Dropdown");
const DropdownCloser_1 = require("../DropdownCloser");
const DropdownContent_1 = require("../DropdownContent");
const DropdownScrollArea_1 = require("../DropdownScrollArea");
const DropdownTrigger_1 = require("../DropdownTrigger");
const STATUS_FILTERED_TEXT = '適用中';
const TRIGGER_BUTTON_TEXT = '絞り込み';
const APPLY_BUTTON_TEXT = '適用';
const CANCEL_BUTTON_TEXT = 'キャンセル';
const RESET_BUTTON_TEXT = '絞り込み条件を解除';
const executeDecorator = (defaultText, decorator) => decorator?.(defaultText) || defaultText;
const filterDropdown = (0, tailwind_variants_1.tv)({
    slots: {
        iconWrapper: [
            'shr-relative shr-leading-none',
            '[&_>_[role="img"]_+_[role="img"]]:shr-absolute [&_>_[role="img"]_+_[role="img"]]:shr-bottom-[2px] [&_>_[role="img"]_+_[role="img"]]:shr-right-[-4px]',
        ],
        fileteredIcon: 'shr-h-[0.5em] shr-w-[0.5em]',
        statusText: 'shr-ms-0.5 shr-text-sm',
        inner: 'shr-p-1.5',
        actionArea: 'shr-border-t-shorthand shr-px-1.5 shr-py-1',
        resetButtonArea: '-shr-ms-0.5',
        rightButtonArea: 'shr-ms-auto',
        message: 'shr-text-right',
    },
    variants: {
        filtered: {
            true: {
                iconWrapper: 'shr-text-main',
            },
        },
        triggerSize: {
            default: {},
            s: {
                iconWrapper: '-shr-translate-x-0.25',
            },
        },
    },
});
const FilterDropdown = ({ isFiltered = false, onApply, onCancel, onReset, children, hasStatusText, decorators, responseMessage, triggerSize, ...props }) => {
    const status = (0, react_1.useMemo)(() => executeDecorator(STATUS_FILTERED_TEXT, decorators?.status), [decorators]);
    const triggerButton = (0, react_1.useMemo)(() => executeDecorator(TRIGGER_BUTTON_TEXT, decorators?.triggerButton), [decorators]);
    const applyButton = (0, react_1.useMemo)(() => executeDecorator(APPLY_BUTTON_TEXT, decorators?.applyButton), [decorators]);
    const cancelButton = (0, react_1.useMemo)(() => executeDecorator(CANCEL_BUTTON_TEXT, decorators?.cancelButton), [decorators]);
    const resetButton = (0, react_1.useMemo)(() => executeDecorator(RESET_BUTTON_TEXT, decorators?.resetButton), [decorators]);
    const filteredIconAriaLabel = (0, react_1.useMemo)(() => (hasStatusText ? undefined : (0, react_innertext_1.default)(status)), [status, hasStatusText]);
    const isRequestProcessing = responseMessage !== undefined && responseMessage.status === 'processing';
    const { iconWrapperStyle, filteredIconStyle, statusTextStyle, innerStyle, actionAreaStyle, resetButtonAreaStyle, rightButtonAreaStyle, messageStyle, } = (0, react_1.useMemo)(() => {
        const { iconWrapper, fileteredIcon, statusText, inner, actionArea, resetButtonArea, rightButtonArea, message, } = filterDropdown();
        return {
            iconWrapperStyle: iconWrapper({ filtered: isFiltered, triggerSize }),
            filteredIconStyle: fileteredIcon(),
            statusTextStyle: statusText(),
            innerStyle: inner(),
            actionAreaStyle: actionArea(),
            resetButtonAreaStyle: resetButtonArea(),
            rightButtonAreaStyle: rightButtonArea(),
            messageStyle: message(),
        };
    }, [isFiltered, triggerSize]);
    return (react_1.default.createElement(Dropdown_1.Dropdown, null,
        react_1.default.createElement(DropdownTrigger_1.DropdownTrigger, null,
            react_1.default.createElement(Button_1.Button, { ...props, suffix: react_1.default.createElement("span", { className: iconWrapperStyle },
                    react_1.default.createElement(Icon_1.FaFilterIcon, null),
                    isFiltered ? (react_1.default.createElement(Icon_1.FaCheckCircleIcon, { "aria-label": filteredIconAriaLabel, className: filteredIconStyle })) : null), size: triggerSize }, triggerButton)),
        hasStatusText && isFiltered ? react_1.default.createElement("span", { className: statusTextStyle }, status) : null,
        react_1.default.createElement(DropdownContent_1.DropdownContent, { controllable: true },
            react_1.default.createElement(DropdownScrollArea_1.DropdownScrollArea, null,
                react_1.default.createElement("div", { className: innerStyle }, children)),
            react_1.default.createElement(Layout_1.Stack, { gap: 0.5, className: actionAreaStyle },
                react_1.default.createElement(Layout_1.Cluster, { gap: 1, align: "center", justify: "space-between" },
                    onReset && (react_1.default.createElement("div", { className: resetButtonAreaStyle },
                        react_1.default.createElement(Button_1.Button, { variant: "text", size: "s", prefix: react_1.default.createElement(Icon_1.FaUndoAltIcon, null), onClick: onReset, disabled: isRequestProcessing }, resetButton))),
                    react_1.default.createElement(Layout_1.Cluster, { gap: { column: 1, row: 0.5 }, justify: "flex-end", className: rightButtonAreaStyle },
                        react_1.default.createElement(DropdownCloser_1.DropdownCloser, null,
                            react_1.default.createElement(Button_1.Button, { onClick: onCancel, disabled: isRequestProcessing }, cancelButton)),
                        react_1.default.createElement(DropdownCloser_1.DropdownCloser, null,
                            react_1.default.createElement(Button_1.Button, { variant: "primary", onClick: onApply, loading: isRequestProcessing }, applyButton)))),
                (responseMessage?.status === 'success' || responseMessage?.status === 'error') && (react_1.default.createElement("div", { className: messageStyle },
                    react_1.default.createElement(ResponseMessage_1.ResponseMessage, { type: responseMessage.status, role: "alert" }, responseMessage.text)))))));
};
exports.FilterDropdown = FilterDropdown;
//# sourceMappingURL=FilterDropdown.js.map