"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useSortDropdown = void 0;
const react_1 = require("react");
const Icon_1 = require("../../Icon");
const style_1 = require("./style");
const SORT_FIELD_LABEL = '並べ替え項目';
const SORT_ORDER_LABEL = '並び順';
const ASC_LABEL = '昇順';
const DESC_LABEL = '降順';
const APPLY_BUTTON_TEXT = '適用';
const CANCEL_BUTTON_TEXT = 'キャンセル';
const useSortDropdown = ({ sortFields, defaultOrder, onApply, decorators }) => {
    const sortFieldLabel = (0, react_1.useMemo)(() => decorators?.sortFieldLabel?.(SORT_FIELD_LABEL) || SORT_FIELD_LABEL, [decorators]);
    const sortOrderLabel = (0, react_1.useMemo)(() => decorators?.sortOrderLabel?.(SORT_ORDER_LABEL) || SORT_ORDER_LABEL, [decorators]);
    const ascLabel = (0, react_1.useMemo)(() => decorators?.ascLabel?.(ASC_LABEL) || ASC_LABEL, [decorators]);
    const descLabel = (0, react_1.useMemo)(() => decorators?.descLabel?.(DESC_LABEL) || DESC_LABEL, [decorators]);
    const applyButtonLabel = (0, react_1.useMemo)(() => decorators?.applyButtonLabel?.(APPLY_BUTTON_TEXT) || APPLY_BUTTON_TEXT, [decorators]);
    const cancelButtonLabel = (0, react_1.useMemo)(() => decorators?.cancelButtonLabel?.(CANCEL_BUTTON_TEXT) || CANCEL_BUTTON_TEXT, [decorators]);
    // 外向きの値
    const [selectedLabel, setSelectedLabel] = (0, react_1.useState)();
    const [checkedOrder, setCheckedOrder] = (0, react_1.useState)(defaultOrder);
    // 内部的な値
    const [innerFields, setInnerFields] = (0, react_1.useState)(sortFields);
    const [innerSelectedField, setInnerSelectedField] = (0, react_1.useState)();
    const [innerCheckedOrder, setCheckedInnerOrder] = (0, react_1.useState)(defaultOrder);
    (0, react_1.useMemo)(() => {
        if (selectedLabel)
            return;
        // 初期値は option に紛れているので、選択されている項目を取得
        const defaultField = sortFields.find((field) => 'selected' in field && field.selected) || sortFields[0];
        setSelectedLabel(defaultField.label);
        setInnerSelectedField(defaultField.label);
    }, [selectedLabel, sortFields]);
    // 外向きな値で構成
    const triggerLabel = (0, react_1.useMemo)(() => {
        const sortLabel = checkedOrder === 'asc' ? ascLabel : descLabel;
        return `${selectedLabel}（${sortLabel}）`;
    }, [ascLabel, descLabel, selectedLabel, checkedOrder]);
    const SortIcon = (0, react_1.useMemo)(() => (checkedOrder === 'asc' ? Icon_1.FaArrowUpWideShortIcon : Icon_1.FaArrowDownWideShortIcon), [checkedOrder]);
    const handleChange = (0, react_1.useCallback)((e) => {
        const select = e.currentTarget;
        const newLabel = select.options[select.selectedIndex].label;
        const newFields = innerFields.map((field) => ({
            ...field,
            selected: field.label === newLabel,
        }));
        setInnerFields(newFields);
        setInnerSelectedField(newLabel);
    }, [innerFields]);
    const handleApply = (0, react_1.useCallback)(() => {
        setSelectedLabel(innerSelectedField);
        setCheckedOrder(innerCheckedOrder);
        onApply({ field: innerSelectedField || '', order: innerCheckedOrder, newfields: innerFields });
    }, [innerCheckedOrder, innerFields, innerSelectedField, onApply]);
    const styles = (0, react_1.useMemo)(() => {
        const { body, select, footer } = (0, style_1.sortDropdownStyle)();
        return {
            bodyStyle: body(),
            selectStyle: select(),
            footerStyle: footer(),
        };
    }, []);
    return {
        setCheckedInnerOrder,
        labels: {
            triggerLabel,
            sortFieldLabel,
            sortOrderLabel,
            ascLabel,
            descLabel,
            applyButtonLabel,
            cancelButtonLabel,
        },
        handler: { handleApply, handleChange },
        innerValues: { innerFields, innerSelectedField, innerCheckedOrder },
        SortIcon,
        styles,
    };
};
exports.useSortDropdown = useSortDropdown;
//# sourceMappingURL=useSortDropdown.js.map