"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Input = void 0;
const react_1 = __importStar(require("react"));
const tailwind_variants_1 = require("tailwind-variants");
const useTailwindTheme_1 = require("../../hooks/useTailwindTheme");
const bgColors = {
    BACKGRUOND: 'background',
    COLUMN: 'column',
    BASE_GREY: 'base-grey',
    OVER_BACKGROUND: 'over-background',
    HEAD: 'head',
    BORDER: 'border',
    ACTION_BACKGROUND: 'action-background',
};
const wrapper = (0, tailwind_variants_1.tv)({
    base: [
        'smarthr-ui-Input',
        'shr-border-shorthand shr-box-border shr-inline-flex shr-cursor-text shr-items-center shr-gap-0.5 shr-rounded-m shr-bg-white shr-px-0.5',
        'contrast-more:shr-border-high-contrast',
        'focus-within:shr-focus-indicator',
    ],
    variants: {
        disabled: {
            true: 'shr-pointer-events-none shr-bg-white-darken [&&&]:shr-border-default/50',
        },
        error: {
            true: '[&]:shr-border-danger',
        },
        readOnly: {
            true: '[&&&]:shr-border-[theme(backgroundColor.background)] [&&&]:shr-bg-background',
        },
    },
});
const inner = (0, tailwind_variants_1.tv)({
    slots: {
        input: [
            'smarthr-ui-Input-input',
            'shr-inline-block shr-w-full shr-grow shr-border-none shr-bg-transparent shr-py-0.75 shr-text-base shr-leading-none shr-text-black shr-outline-none shr-outline-0',
            'placeholder:shr-text-grey',
            'disabled:shr-text-disabled disabled:shr-opacity-100',
            'shr-h-[theme(fontSize.base)]',
        ],
        affix: 'shr-flex shr-shrink-0 shr-items-center shr-text-grey',
    },
});
exports.Input = (0, react_1.forwardRef)(({ onFocus, onBlur, autoFocus, prefix, suffix, className, width, disabled, error, readOnly, bgColor, ...props }, ref) => {
    const innerRef = (0, react_1.useRef)(null);
    (0, react_1.useImperativeHandle)(ref, () => innerRef.current);
    const handleFocus = (0, react_1.useMemo)(() => {
        if (!onFocus) {
            return undefined;
        }
        return (e) => onFocus(e);
    }, [onFocus]);
    const handleBlur = (0, react_1.useMemo)(() => {
        if (!onBlur) {
            return undefined;
        }
        return (e) => onBlur(e);
    }, [onBlur]);
    const handleWheel = (0, react_1.useMemo)(() => (props.type === 'number' ? disableWheel : undefined), [props.type]);
    (0, react_1.useEffect)(() => {
        if (autoFocus && innerRef.current) {
            innerRef.current.focus();
        }
    }, [autoFocus]);
    const { backgroundColor } = (0, useTailwindTheme_1.useTheme)();
    const wrapperStyleProps = (0, react_1.useMemo)(() => {
        const wrapperStyle = wrapper({ disabled, error, readOnly, className });
        const color = bgColor
            ? backgroundColor[bgColors[bgColor]]
            : undefined;
        return {
            className: wrapperStyle,
            style: {
                borderColor: color,
                backgroundColor: color,
                width: typeof width === 'number' ? `${width}px` : width,
            },
        };
    }, [backgroundColor, bgColor, className, disabled, error, readOnly, width]);
    const { input, affix } = inner();
    return (react_1.default.createElement("span", { ...wrapperStyleProps, onClick: () => innerRef.current?.focus(), role: "presentation" },
        prefix && (react_1.default.createElement("span", { className: affix({ className: 'smarthr-ui-Input-prefix' }) }, prefix)),
        react_1.default.createElement("input", { ...props, onFocus: handleFocus, onBlur: handleBlur, onWheel: handleWheel, disabled: disabled, readOnly: readOnly, ref: innerRef, "aria-invalid": error || undefined, className: input() }),
        suffix && (react_1.default.createElement("span", { className: affix({ className: 'smarthr-ui-Input-suffix' }) }, suffix))));
});
const disableWheel = (e) => {
    // wheel イベントに preventDefault はないため
    e.target && e.target.blur();
};
//# sourceMappingURL=Input.js.map