"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InputFile = void 0;
const react_1 = __importStar(require("react"));
const tailwind_variants_1 = require("tailwind-variants");
const Base_1 = require("../Base");
const Button_1 = require("../Button");
const Icon_1 = require("../Icon");
const Layout_1 = require("../Layout");
const inputFile = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: 'smarthr-ui-InputFile shr-block',
        fileList: ['smarthr-ui-InputFile-fileList', 'shr-list-none shr-self-stretch shr-text-base'],
        fileItem: 'shr-flex shr-items-center',
        inputWrapper: [
            'shr-border-shorthand shr-relative shr-inline-flex shr-rounded-m shr-bg-white shr-font-bold shr-leading-none',
            'contrast-more:shr-border-high-contrast',
            'focus-within:shr-focus-indicator',
        ],
        input: [
            'smarthr-ui-InputFile-input',
            'shr-absolute shr-left-0 shr-top-0 shr-h-full shr-w-full shr-opacity-0',
            'file:shr-h-full file:shr-w-full file:shr-cursor-pointer',
            'file:disabled:shr-cursor-not-allowed',
        ],
        prefix: 'shr-me-0.5 shr-inline-flex',
    },
    variants: {
        size: {
            default: {
                inputWrapper: 'shr-px-1 shr-py-0.75 shr-text-base',
            },
            s: {
                inputWrapper: 'shr-p-0.5 shr-text-sm',
            },
        },
        disabled: {
            true: {
                inputWrapper: 'shr-border-default/50 shr-bg-white/50 shr-text-disabled',
            },
            false: {
                inputWrapper: 'hover:shr-border-darken hover:shr-bg-white-darken hover:shr-text-black',
            },
        },
        error: {
            true: {
                inputWrapper: '[&&&]:shr-border-danger',
            },
        },
    },
});
const DESTROY_BUTTON_TEXT = '削除';
exports.InputFile = (0, react_1.forwardRef)(({ className, size = 'default', label, hasFileList = true, onChange, disabled = false, error, decorators, ...props }, ref) => {
    const [files, setFiles] = (0, react_1.useState)([]);
    const labelId = (0, react_1.useId)();
    const { wrapper, fileList, fileItem, inputWrapper, input, prefix } = inputFile();
    const wrapperStyle = (0, react_1.useMemo)(() => wrapper({ className }), [className, wrapper]);
    const inputWrapperStyle = (0, react_1.useMemo)(() => inputWrapper({ size, disabled, error }), [disabled, error, inputWrapper, size]);
    // Safari において、input.files への直接代入時に onChange が発火することを防ぐためのフラグ
    const isUpdatingFilesDirectly = (0, react_1.useRef)(false);
    const inputRef = (0, react_1.useRef)(null);
    (0, react_1.useImperativeHandle)(ref, () => inputRef.current);
    const destroyButtonText = (0, react_1.useMemo)(() => decorators?.destroy?.(DESTROY_BUTTON_TEXT) || DESTROY_BUTTON_TEXT, [decorators]);
    const updateFiles = (0, react_1.useCallback)((newFiles) => {
        onChange && onChange(newFiles);
        setFiles(newFiles);
    }, [setFiles, onChange]);
    const handleChange = (0, react_1.useCallback)((e) => {
        if (isUpdatingFilesDirectly.current) {
            return;
        }
        const newFiles = Array.from(e.target.files ?? []);
        updateFiles(newFiles);
    }, [isUpdatingFilesDirectly, updateFiles]);
    const handleDelete = (0, react_1.useCallback)((index) => {
        if (!inputRef.current) {
            return;
        }
        const newFiles = files.filter((_, i) => index !== i);
        updateFiles(newFiles);
        const buff = new DataTransfer();
        newFiles.forEach((file) => {
            buff.items.add(file);
        });
        isUpdatingFilesDirectly.current = true;
        inputRef.current.files = buff.files;
        isUpdatingFilesDirectly.current = false;
    }, [files, isUpdatingFilesDirectly, inputRef, updateFiles]);
    return (react_1.default.createElement(Layout_1.Stack, { align: "flex-start", className: wrapperStyle },
        !disabled && hasFileList && files.length > 0 && (react_1.default.createElement(Base_1.BaseColumn, { as: "ul", padding: { block: 0.5, inline: 1 }, className: fileList() }, files.map((file, index) => (react_1.default.createElement("li", { key: `${file.name}-${index}`, className: fileItem() },
            react_1.default.createElement("span", { className: "smarthr-ui-InputFile-fileName" }, file.name),
            react_1.default.createElement(Button_1.Button, { variant: "text", prefix: react_1.default.createElement(Icon_1.FaTrashAltIcon, null), onClick: () => handleDelete(index), className: "smarthr-ui-InputFile-deleteButton" }, destroyButtonText)))))),
        react_1.default.createElement("span", { className: inputWrapperStyle },
            react_1.default.createElement("input", { ...props, type: "file", onChange: handleChange, disabled: disabled, className: input(), ref: inputRef, "aria-invalid": error || undefined, "aria-labelledby": labelId }),
            react_1.default.createElement("span", { className: prefix() },
                react_1.default.createElement(Icon_1.FaFolderOpenIcon, null)),
            react_1.default.createElement("span", { id: labelId, "aria-hidden": "true" }, label))));
});
//# sourceMappingURL=InputFile.js.map