"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Th = void 0;
const react_1 = __importStar(require("react"));
const tailwind_variants_1 = require("tailwind-variants");
const Button_1 = require("../Button");
const Icon_1 = require("../Icon");
const VisuallyHiddenText_1 = require("../VisuallyHiddenText");
const useReelShadow_1 = require("./useReelShadow");
const SORT_DIRECTION_LABEL = {
    asc: '昇順',
    desc: '降順',
    none: '並び替えなし',
};
const thWrapper = (0, tailwind_variants_1.tv)({
    base: [
        'smarthr-ui-Th',
        'shr-px-1 shr-py-0.75 shr-text-left shr-align-middle shr-text-sm shr-font-bold shr-leading-tight shr-text-black',
        'aria-[sort]:shr-cursor-pointer',
        'hover:aria-[sort]:shr-bg-head-darken',
        '[&:has(:focus-visible)]:aria-[sort]:shr-focus-indicator',
        '[&[aria-sort=none]_.smarthr-ui-Icon]:forced-colors:shr-fill-[GrayText]',
        '[&[aria-sort=ascending]_.smarthr-ui-Icon:first-of-type]:forced-colors:shr-fill-[CanvasText] [&[aria-sort=ascending]_.smarthr-ui-Icon:last-of-type]:forced-colors:shr-fill-[GrayText]',
        '[&[aria-sort=descending]_.smarthr-ui-Icon:first-of-type]:forced-colors:shr-fill-[GrayText] [&[aria-sort=descending]_.smarthr-ui-Icon:last-of-type]:forced-colors:shr-fill-[CanvasText]',
    ],
    variants: {
        fixed: {
            true: [
                /* これ以降の記述はTableReel内で'fixed'を利用した際に追従させるために必要 */
                'fixedElement',
                '[&.fixed]:shr-sticky [&.fixed]:shr-right-0 [&.fixed]:after:shr-opacity-100',
            ],
        },
    },
});
const Th = ({ children, sort, onSort, decorators, fixed = false, className, ...props }) => {
    const styles = (0, react_1.useMemo)(() => {
        const thWrapperStyle = thWrapper({ className, fixed });
        const reelShadowStyles = fixed ? (0, useReelShadow_1.reelShadowStyle)({ showShadow: false, direction: 'right' }) : '';
        return `${thWrapperStyle} ${reelShadowStyles}`.trim();
    }, [className, fixed]);
    const sortLabel = (0, react_1.useMemo)(() => sort &&
        (decorators?.sortDirectionIconAlt?.(SORT_DIRECTION_LABEL[sort], { sort }) ||
            SORT_DIRECTION_LABEL[sort]), [decorators, sort]);
    const ariaSortProps = (0, react_1.useMemo)(() => sort && {
        'aria-sort': sort === 'none' ? 'none' : `${sort}ending`,
    }, [sort]);
    return (react_1.default.createElement("th", { ...ariaSortProps, ...props, className: styles }, sort ? (react_1.default.createElement(SortButton, { onClick: onSort },
        children,
        react_1.default.createElement(SortIcon, { sort: sort }),
        react_1.default.createElement(VisuallyHiddenText_1.VisuallyHiddenText, null, sortLabel))) : (children)));
};
exports.Th = Th;
const sortButton = (0, tailwind_variants_1.tv)({
    base: [
        '-shr-mx-1 -shr-my-0.75 shr-inline-flex shr-w-full shr-justify-between shr-gap-x-0.5 shr-px-1 shr-py-0.75 shr-font-bold',
        // UnstyledButton に stretch がなぜか指定されてて負けてしまうため（UnstyledButton を見直した方がよさそう）
        '[&]:shr-items-center',
    ],
});
const SortButton = ({ className, ...props }) => {
    const sortButtonStyle = (0, react_1.useMemo)(() => sortButton({ className }), [className]);
    return react_1.default.createElement(Button_1.UnstyledButton, { ...props, className: sortButtonStyle });
};
const sortIcon = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: 'shr-inline-flex shr-flex-col',
        upIcon: 'shr-text-base',
        downIcon: '-shr-mt-em shr-text-base',
    },
    variants: {
        sort: {
            asc: {
                upIcon: 'shr-text-black',
                downIcon: 'shr-text-disabled',
            },
            desc: {
                upIcon: 'shr-text-disabled',
                downIcon: 'shr-text-black',
            },
            none: {
                upIcon: 'shr-text-disabled',
                downIcon: 'shr-text-disabled',
            },
        },
    },
});
const SortIcon = ({ sort }) => {
    const { wrapperStyle, upIconStyle, downIconStyle } = (0, react_1.useMemo)(() => {
        const sortIconStyle = sortIcon();
        return {
            wrapperStyle: sortIconStyle.wrapper(),
            upIconStyle: sortIconStyle.upIcon({ sort }),
            downIconStyle: sortIconStyle.downIcon({ sort }),
        };
    }, [sort]);
    return (react_1.default.createElement("span", { className: wrapperStyle },
        react_1.default.createElement(Icon_1.FaSortUpIcon, { className: upIconStyle }),
        react_1.default.createElement(Icon_1.FaSortDownIcon, { className: downIconStyle })));
};
//# sourceMappingURL=Th.js.map