"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Textarea = void 0;
const react_1 = __importStar(require("react"));
const tailwind_variants_1 = require("tailwind-variants");
const useId_1 = require("../../hooks/useId");
const useTailwindTheme_1 = require("../../hooks/useTailwindTheme");
const createFontSize_1 = require("../../themes/createFontSize");
const getStringLength = (value) => {
    const formattedValue = typeof value === 'number' || typeof value === 'string'
        ? `${value}`
        : Array.isArray(value)
            ? value.join(',')
            : '';
    // https://developer.mozilla.org/ja/docs/Web/JavaScript/Reference/Global_Objects/String/charCodeAt
    const surrogatePairs = /[\uD800-\uDBFF][\uDC00-\uDFFF]/g;
    return formattedValue.length - (formattedValue.match(surrogatePairs) || []).length;
};
const TEXT_BEFORE_MAXLETTERS_COUNT = 'あと';
const TEXT_AFTER_MAXLETTERS_COUNT = '文字';
const textarea = (0, tailwind_variants_1.tv)({
    slots: {
        textareaEl: [
            'smarthr-ui-Textarea-textarea',
            'shr-border-shorthand shr-my-[unset] shr-box-border shr-rounded-m shr-bg-white shr-p-0.5 shr-text-base shr-leading-normal shr-text-black shr-opacity-100',
            'contrast-more:shr-border-high-contrast',
            'placeholder:shr-text-grey',
            'focus-visible:shr-focus-indicator',
            'disabled:shr-pointer-events-none disabled:shr-bg-column disabled:shr-text-disabled disabled:placeholder:shr-text-disabled',
        ],
        counter: 'smarthr-ui-Textarea-counter shr-block shr-text-sm',
        counterText: 'shr-font-bold',
    },
    variants: {
        error: {
            true: {
                textareaEl: 'shr-border-danger',
                counterText: 'shr-text-danger',
            },
            false: {
                textareaEl: 'shr-border-default',
                counterText: 'shr-text-grey',
            },
        },
    },
    defaultVariants: {
        error: false,
    },
});
exports.Textarea = (0, react_1.forwardRef)(({ autoFocus, maxLetters, width, className, autoResize = false, maxRows = Infinity, rows = 2, onInput, decorators, error, ...props }, ref) => {
    const maxLettersId = (0, useId_1.useId)();
    const actualMaxLettersId = maxLetters ? maxLettersId : undefined;
    const { lineHeight } = (0, useTailwindTheme_1.useTheme)();
    const textareaRef = (0, react_1.useRef)(null);
    const currentValue = props.defaultValue || props.value;
    const [interimRows, setInterimRows] = (0, react_1.useState)(rows);
    const [count, setCount] = (0, react_1.useState)(currentValue ? getStringLength(currentValue) : 0);
    const beforeMaxLettersCount = (0, react_1.useMemo)(() => decorators?.beforeMaxLettersCount?.(TEXT_BEFORE_MAXLETTERS_COUNT) ||
        TEXT_BEFORE_MAXLETTERS_COUNT, [decorators]);
    const afterMaxLettersCount = (0, react_1.useMemo)(() => decorators?.afterMaxLettersCount?.(TEXT_AFTER_MAXLETTERS_COUNT) ||
        TEXT_AFTER_MAXLETTERS_COUNT, [decorators]);
    (0, react_1.useImperativeHandle)(ref, () => textareaRef.current);
    (0, react_1.useEffect)(() => {
        if (autoFocus && textareaRef && textareaRef.current) {
            textareaRef.current.focus();
        }
    }, [autoFocus]);
    const onKeyUp = (0, react_1.useMemo)(() => maxLetters
        ? (event) => {
            setCount(getStringLength(event.currentTarget.value));
        }
        : undefined, [maxLetters]);
    const handleInput = (0, react_1.useCallback)((e) => {
        if (!autoResize) {
            return onInput && onInput(e);
        }
        const previousRows = e.target.rows;
        // 消したことを検知できないので必ず初期化
        e.target.rows = rows;
        const currentRows = Math.floor(e.target.scrollHeight / (createFontSize_1.defaultHtmlFontSize * Number(lineHeight.normal)));
        if (previousRows === currentRows) {
            e.target.rows = currentRows;
        }
        else if (maxRows < currentRows) {
            // 最大まで達したとき高さが潰れないように代入
            e.target.rows = maxRows;
        }
        setInterimRows(currentRows < maxRows ? currentRows : maxRows);
        onInput && onInput(e);
    }, [autoResize, lineHeight.normal, maxRows, onInput, rows]);
    const { textareaStyleProps, counterStyle, counterTextStyle } = (0, react_1.useMemo)(() => {
        const { textareaEl, counter, counterText } = textarea();
        return {
            textareaStyleProps: {
                className: textareaEl({ error, className }),
                style: { width: typeof width === 'number' ? `${width}px` : width },
            },
            counterStyle: counter(),
            counterTextStyle: counterText({ error: !!(maxLetters && maxLetters - count <= 0) }),
        };
    }, [className, count, error, maxLetters, width]);
    const body = (
    // eslint-disable-next-line smarthr/a11y-input-has-name-attribute
    react_1.default.createElement("textarea", { ...props, ...textareaStyleProps, "aria-describedby": actualMaxLettersId, onKeyUp: onKeyUp, ref: textareaRef, "aria-invalid": error || undefined, rows: interimRows, onInput: handleInput }));
    return maxLetters ? (react_1.default.createElement("span", null,
        body,
        react_1.default.createElement("span", { className: counterStyle, id: actualMaxLettersId },
            beforeMaxLettersCount,
            react_1.default.createElement("span", { className: counterTextStyle },
                maxLetters - count,
                "/",
                maxLetters),
            afterMaxLettersCount))) : (body);
});
//# sourceMappingURL=Textarea.js.map