"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Tooltip = void 0;
const react_1 = __importStar(require("react"));
const react_dom_1 = require("react-dom");
const tailwind_variants_1 = require("tailwind-variants");
const useEnhancedEffect_1 = require("../../hooks/useEnhancedEffect");
const useId_1 = require("../../hooks/useId");
const TooltipPortal_1 = require("./TooltipPortal");
const subscribeFullscreenChange = (callback) => {
    window.addEventListener('fullscreenchange', callback);
    return () => {
        window.removeEventListener('fullscreenchange', callback);
    };
};
const getFullscreenElement = () => document.fullscreenElement;
const getFullscreenElementOnSSR = () => null;
const tooltip = (0, tailwind_variants_1.tv)({
    base: [
        'smarthr-ui-Tooltip',
        'shr-inline-block shr-max-w-full shr-overflow-y-hidden',
        /* inline-block に overflow: visible 以外を指定すると、vertical-align が bottom margin edge に揃ってしまう
         * https://ja.stackoverflow.com/questions/2603/ */
        'shr-align-bottom',
        'focus-visible:shr-focus-indicator',
    ],
    variants: {
        isIcon: {
            true: 'shr-leading-[0]',
        },
    },
});
const Tooltip = ({ message, children, triggerType, multiLine, ellipsisOnly = false, horizontal = 'left', vertical = 'bottom', tabIndex = 0, ariaDescribedbyTarget = 'wrapper', className, onPointerEnter, onPointerLeave, onTouchStart, onTouchEnd, onFocus, onBlur, ...props }) => {
    const [portalRoot, setPortalRoot] = (0, react_1.useState)(null);
    const [isVisible, setIsVisible] = (0, react_1.useState)(false);
    const [rect, setRect] = (0, react_1.useState)(null);
    const ref = (0, react_1.useRef)(null);
    const tooltipId = (0, useId_1.useId)();
    const fullscreenElement = (0, react_1.useSyncExternalStore)(subscribeFullscreenChange, getFullscreenElement, getFullscreenElementOnSSR);
    (0, useEnhancedEffect_1.useEnhancedEffect)(() => {
        setPortalRoot(fullscreenElement ?? document.body);
    }, [fullscreenElement]);
    const getHandlerToShow = (handler) => (e) => {
        handler && handler(e);
        if (!ref.current) {
            return;
        }
        if (ellipsisOnly) {
            const outerWidth = parseInt(window
                .getComputedStyle(ref.current.parentNode, null)
                .width.match(/\d+/)[0], 10);
            const wrapperWidth = ref.current.clientWidth;
            const existsEllipsis = outerWidth >= 0 && outerWidth <= wrapperWidth;
            if (!existsEllipsis) {
                return;
            }
        }
        setRect(ref.current.getBoundingClientRect());
        setIsVisible(true);
    };
    const getHandlerToHide = (handler) => (e) => {
        handler && handler(e);
        setIsVisible(false);
    };
    const isIcon = triggerType === 'icon';
    const styles = tooltip({ isIcon, className });
    const childrenWithProps = ariaDescribedbyTarget === 'inner'
        ? react_1.default.cloneElement(children, { 'aria-describedby': tooltipId })
        : children;
    return (
    // eslint-disable-next-line jsx-a11y/no-static-element-interactions,smarthr/a11y-delegate-element-has-role-presentation
    react_1.default.createElement("span", { ...props, "aria-describedby": ariaDescribedbyTarget === 'wrapper' ? tooltipId : undefined, ref: ref, onPointerEnter: getHandlerToShow(onPointerEnter), onTouchStart: getHandlerToShow(onTouchStart), onFocus: getHandlerToShow(onFocus), onPointerLeave: getHandlerToHide(onPointerLeave), onTouchEnd: getHandlerToHide(onTouchEnd), onBlur: getHandlerToHide(onBlur), tabIndex: tabIndex, className: styles },
        portalRoot &&
            (0, react_dom_1.createPortal)(react_1.default.createElement(TooltipPortal_1.TooltipPortal, { message: message, id: tooltipId, isVisible: isVisible, parentRect: rect, isIcon: isIcon, isMultiLine: multiLine, horizontal: horizontal, vertical: vertical, fullscreenElement: fullscreenElement }), portalRoot),
        childrenWithProps));
};
exports.Tooltip = Tooltip;
//# sourceMappingURL=Tooltip.js.map