"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TooltipPortal = void 0;
const react_1 = __importStar(require("react"));
const tailwind_variants_1 = require("tailwind-variants");
const Balloon_1 = require("../Balloon");
const tooltipHelper_1 = require("./tooltipHelper");
const tooltipPortal = (0, tailwind_variants_1.tv)({
    slots: {
        container: 'smarthr-ui-Tooltip-popup shr-absolute shr-z-overlap aria-hidden:shr-hidden',
        balloon: '',
        balloonText: 'shr-m-0 shr-px-1 shr-py-0.5',
    },
    variants: {
        isMultiLine: {
            true: {
                balloon: 'shr-max-w-full [&&&]:shr-whitespace-normal',
            },
        },
    },
});
const TooltipPortal = ({ message, id, isVisible, parentRect, isIcon = false, isMultiLine = false, horizontal, vertical, fullscreenElement, }) => {
    const portalRef = (0, react_1.useRef)(null);
    const [rect, setRect] = (0, react_1.useState)({
        top: 0,
        left: 0,
        $width: 0,
        $height: 0,
    });
    const [actualHorizontal, setActualHorizontal] = (0, react_1.useState)(horizontal === 'auto' ? null : horizontal);
    const [actualVertical, setActualVertical] = (0, react_1.useState)(vertical === 'auto' ? null : vertical);
    const outerMargin = 10;
    (0, react_1.useEffect)(() => {
        if (!portalRef.current || !parentRect) {
            return;
        }
        const { offsetWidth, offsetHeight } = portalRef.current;
        if (vertical === 'auto') {
            const requiredHeight = offsetHeight + outerMargin;
            const topSpace = parentRect.top;
            const bottomSpace = window.innerHeight - parentRect.bottom;
            setActualVertical(() => {
                if (topSpace > requiredHeight) {
                    return 'bottom';
                }
                else if (bottomSpace > requiredHeight || bottomSpace > topSpace) {
                    return 'top';
                }
                else {
                    return 'bottom';
                }
            });
        }
        if (horizontal === 'auto') {
            const requiredWidth = offsetWidth + outerMargin;
            const leftSpace = vertical === 'middle' ? parentRect.left : parentRect.right;
            const rightSpace = vertical === 'middle'
                ? window.innerWidth - parentRect.right
                : window.innerWidth - parentRect.left;
            setActualHorizontal(() => {
                if (rightSpace > requiredWidth) {
                    return 'left';
                }
                else if (leftSpace > requiredWidth || leftSpace > rightSpace) {
                    return 'right';
                }
                else {
                    return 'left';
                }
            });
        }
    }, [horizontal, parentRect, vertical]);
    (0, react_1.useEffect)(() => {
        if (!isVisible || !portalRef.current || !actualHorizontal || !actualVertical || !parentRect) {
            return;
        }
        const scrollOffsetTop = fullscreenElement ? fullscreenElement.scrollTop : window.scrollY;
        const scrollOffsetLeft = fullscreenElement ? fullscreenElement.scrollLeft : window.scrollX;
        const { offsetWidth, offsetHeight } = portalRef.current;
        setRect((0, tooltipHelper_1.getTooltipRect)({
            parentRect,
            scrollOffset: {
                top: scrollOffsetTop,
                left: scrollOffsetLeft,
            },
            tooltipSize: {
                width: offsetWidth,
                height: offsetHeight,
            },
            vertical: actualVertical,
            horizontal: actualHorizontal,
            isIcon,
            outerMargin,
        }));
    }, [actualHorizontal, actualVertical, fullscreenElement, isIcon, isVisible, parentRect]);
    const { containerStyleProps, balloonStyle, balloonTextStyle } = (0, react_1.useMemo)(() => {
        const { container, balloon, balloonText } = tooltipPortal();
        return {
            containerStyleProps: {
                className: container(),
                style: {
                    top: rect.top,
                    left: rect.left,
                    width: rect.$width > 0 ? `${rect.$width}px` : undefined,
                    height: rect.$height > 0 ? `${rect.$height}px` : undefined,
                    maxWidth: isMultiLine && parentRect ? `${parentRect.width}px` : undefined,
                },
            },
            balloonStyle: balloon({ isMultiLine }),
            balloonTextStyle: balloonText(),
        };
    }, [isMultiLine, parentRect, rect.$height, rect.$width, rect.left, rect.top]);
    return (react_1.default.createElement("div", { ...containerStyleProps, id: id, ref: portalRef, role: "tooltip", "aria-hidden": !isVisible },
        react_1.default.createElement(Balloon_1.Balloon, { horizontal: actualHorizontal || 'left', vertical: actualVertical || 'bottom', className: balloonStyle },
            react_1.default.createElement("p", { className: balloonTextStyle }, message))));
};
exports.TooltipPortal = TooltipPortal;
//# sourceMappingURL=TooltipPortal.js.map