"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createShadow = exports.defaultShadow = void 0;
const polished_1 = require("polished");
const styled_components_1 = require("styled-components");
const lodash_1 = require("../libs/lodash");
const createColor_1 = require("./createColor");
const createOutline = (color) => `0 0 0 2px white, 0 0 0 4px ${color}`;
const defaultOutline = createOutline(createColor_1.defaultColor.OUTLINE);
const defaultOutlineMargin = '4px';
const createLayerShadow = (depth) => depth === 0
    ? 'none'
    : `0 ${2 ** (depth - 1)}px ${2 ** depth}px ${depth - 1 > 0 ? `${2 ** (depth - 2)}px` : 0} ${createColor_1.defaultColor.TRANSPARENCY_30}`;
exports.defaultShadow = {
    BASE: `${createColor_1.defaultColor.TRANSPARENCY_15} 0 0 4px 0`,
    DIALOG: `${createColor_1.defaultColor.TRANSPARENCY_30} 0 4px 10px 0`,
    LAYER0: createLayerShadow(0),
    LAYER1: createLayerShadow(1),
    LAYER2: createLayerShadow(2),
    LAYER3: createLayerShadow(3),
    LAYER4: createLayerShadow(4),
    OUTLINE: defaultOutline,
    OUTLINE_MARGIN: defaultOutlineMargin,
    UNDERLINE: '0 1px 0 0',
    INPUT_HOVER: `0 0 0 2px ${(0, polished_1.transparentize)(0.78, createColor_1.defaultColor.MAIN)}`,
};
const createFocusIndicatorStyles = (outline) => (0, styled_components_1.css) `
  outline: none;
  isolation: isolate;
  box-shadow: ${outline};
`;
const createShadow = (userShadow = {}, userColor = {}) => {
    const outline = createOutline(userColor.OUTLINE || createColor_1.defaultColor.OUTLINE);
    const created = (0, lodash_1.merge)({
        ...exports.defaultShadow,
        OUTLINE: outline,
        focusIndicatorStyles: createFocusIndicatorStyles(outline),
    }, userShadow);
    return created;
};
exports.createShadow = createShadow;
//# sourceMappingURL=createShadow.js.map